@@ -1,22 +1,8 @@
 #!/usr/bin/python3
 #
-# Copyright (C) 2017-2018 Dell Inc.
+# Copyright (C) 2017-2018 Dell, Inc.
 #
-# Licensed under the GNU General Public License Version 2
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# SPDX-License-Identifier: LGPL-2.1+
 #
 import os
 import subprocess
@@ -79,14 +65,16 @@ out = tempfile.NamedTemporaryFile(dir='.', delete=True)
 with open(out.name, 'w') as wfd:
     for line in lines:
         if line.startswith("FROM %%%ARCH_PREFIX%%%"):
-            if OS == "debian" and SUBOS == "i386":
+            if (OS == "debian" or OS == "ubuntu") and SUBOS == "i386":
                 replace = SUBOS + "/"
             else:
                 replace = ''
             wfd.write(line.replace("%%%ARCH_PREFIX%%%", replace))
         elif line == "%%%INSTALL_DEPENDENCIES_COMMAND%%%\n":
-            if OS == "fedora":
+            if OS == "fedora" or OS == 'flatpak':
                 wfd.write("RUN dnf --enablerepo=updates-testing -y install \\\n")
+            elif OS == "centos":
+                wfd.write("RUN yum -y install \\\n")
             elif OS == "debian" or OS == "ubuntu":
                 wfd.write("RUN apt update -qq && \\\n")
                 wfd.write("\tapt install -yq --no-install-recommends\\\n")
@@ -108,4 +96,10 @@ with open(out.name, 'w') as wfd:
         else:
             wfd.write(line)
     wfd.flush()
-    subprocess.check_call(["docker", "build", "-t", "fwupd-%s" % TARGET, "-f", "./%s" % os.path.basename(out.name), "."])
+    args = ["docker", "build", "-t", "fwupd-%s" % TARGET]
+    if 'http_proxy' in os.environ:
+        args += ['--build-arg=http_proxy=%s' % os.environ['http_proxy']]
+    if 'https_proxy' in os.environ:
+        args += ['--build-arg=https_proxy=%s' % os.environ['https_proxy']]
+    args += [ "-f", "./%s" % os.path.basename(out.name), "."]
+    subprocess.check_call(args)
