@@ -47,6 +47,7 @@ typedef struct {
 	gchar				*version;
 	gchar				*version_lowest;
 	gchar				*version_bootloader;
+	FwupdVersionFormat		 version_format;
 	GPtrArray			*checksums;
 	guint32				 flashes_left;
 	guint32				 install_duration;
@@ -57,6 +58,12 @@ typedef struct {
 	FwupdDevice			*parent;
 } FwupdDevicePrivate;
 
+enum {
+	PROP_0,
+	PROP_VERSION_FORMAT,
+	PROP_LAST
+};
+
 G_DEFINE_TYPE_WITH_PRIVATE (FwupdDevice, fwupd_device, G_TYPE_OBJECT)
 #define GET_PRIVATE(o) (fwupd_device_get_instance_private (o))
 
@@ -1050,6 +1057,8 @@ fwupd_device_incorporate (FwupdDevice *self, FwupdDevice *donor)
 		fwupd_device_set_version_lowest (self, priv_donor->version_lowest);
 	if (priv->version_bootloader == NULL)
 		fwupd_device_set_version_bootloader (self, priv_donor->version_bootloader);
+	if (priv->version_format == FWUPD_VERSION_FORMAT_UNKNOWN)
+		fwupd_device_set_version_format (self, priv_donor->version_format);
 	for (guint i = 0; i < priv_donor->guids->len; i++) {
 		const gchar *tmp = g_ptr_array_index (priv_donor->guids, i);
 		fwupd_device_add_guid (self, tmp);
@@ -1214,6 +1223,11 @@ fwupd_device_to_variant_full (FwupdDevice *device, FwupdDeviceFlags flags)
 				       FWUPD_RESULT_KEY_UPDATE_STATE,
 				       g_variant_new_uint32 (priv->update_state));
 	}
+	if (priv->version_format != FWUPD_VERSION_FORMAT_UNKNOWN) {
+		g_variant_builder_add (&builder, "{sv}",
+				       FWUPD_RESULT_KEY_VERSION_FORMAT,
+				       g_variant_new_uint32 (priv->version_format));
+	}
 	if (flags & FWUPD_DEVICE_FLAG_TRUSTED) {
 		if (priv->serial != NULL) {
 			g_variant_builder_add (&builder, "{sv}",
@@ -1383,6 +1397,10 @@ fwupd_device_from_key_value (FwupdDevice *device, const gchar *key, GVariant *va
 		fwupd_device_set_update_state (device, g_variant_get_uint32 (value));
 		return;
 	}
+	if (g_strcmp0 (key, FWUPD_RESULT_KEY_VERSION_FORMAT) == 0) {
+		fwupd_device_set_version_format (device, g_variant_get_uint32 (value));
+		return;
+	}
 }
 
 static void
@@ -1477,6 +1495,41 @@ fwupd_device_set_update_state (FwupdDevice *device, FwupdUpdateState update_stat
 	priv->update_state = update_state;
 }
 
+/**
+ * fwupd_device_get_version_format:
+ * @device: A #FwupdDevice
+ *
+ * Gets the update state.
+ *
+ * Returns: the update state, or %FWUPD_VERSION_FORMAT_UNKNOWN if unset
+ *
+ * Since: 1.2.9
+ **/
+FwupdVersionFormat
+fwupd_device_get_version_format (FwupdDevice *device)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+	g_return_val_if_fail (FWUPD_IS_DEVICE (device), FWUPD_VERSION_FORMAT_UNKNOWN);
+	return priv->version_format;
+}
+
+/**
+ * fwupd_device_set_version_format:
+ * @device: A #FwupdDevice
+ * @version_format: the state, e.g. %FWUPD_VERSION_FORMAT_PENDING
+ *
+ * Sets the update state.
+ *
+ * Since: 1.2.9
+ **/
+void
+fwupd_device_set_version_format (FwupdDevice *device, FwupdVersionFormat version_format)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	priv->version_format = version_format;
+}
+
 /**
  * fwupd_device_get_update_message:
  * @device: A #FwupdDevice
@@ -1690,6 +1743,8 @@ fwupd_device_to_json (FwupdDevice *device, JsonBuilder *builder)
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_VERSION, priv->version);
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_VERSION_LOWEST, priv->version_lowest);
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_VERSION_BOOTLOADER, priv->version_bootloader);
+	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_VERSION_FORMAT,
+				      fwupd_version_format_to_string (priv->version_format));
 	fwupd_device_json_add_int (builder, FWUPD_RESULT_KEY_FLASHES_LEFT, priv->flashes_left);
 	if (priv->icons->len > 0) {
 		json_builder_set_member_name (builder, "Icons");
@@ -1778,6 +1833,8 @@ fwupd_device_to_string (FwupdDevice *device)
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_VERSION, priv->version);
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_VERSION_LOWEST, priv->version_lowest);
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_VERSION_BOOTLOADER, priv->version_bootloader);
+	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_VERSION_FORMAT,
+			  fwupd_version_format_to_string (priv->version_format));
 	if (priv->flashes_left < 2)
 		fwupd_pad_kv_int (str, FWUPD_RESULT_KEY_FLASHES_LEFT, priv->flashes_left);
 	if (priv->icons->len > 0) {
@@ -1806,11 +1863,54 @@ fwupd_device_to_string (FwupdDevice *device)
 	return g_string_free (str, FALSE);
 }
 
+static void
+fwupd_device_get_property (GObject *object, guint prop_id,
+			   GValue *value, GParamSpec *pspec)
+{
+	FwupdDevice *self = FWUPD_DEVICE (object);
+	FwupdDevicePrivate *priv = GET_PRIVATE (self);
+	switch (prop_id) {
+	case PROP_VERSION_FORMAT:
+		g_value_set_uint (value, priv->version_format);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+fwupd_device_set_property (GObject *object, guint prop_id,
+			   const GValue *value, GParamSpec *pspec)
+{
+	FwupdDevice *self = FWUPD_DEVICE (object);
+	switch (prop_id) {
+	case PROP_VERSION_FORMAT:
+		fwupd_device_set_version_format (self, g_value_get_uint (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
 static void
 fwupd_device_class_init (FwupdDeviceClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GParamSpec *pspec;
+
 	object_class->finalize = fwupd_device_finalize;
+	object_class->get_property = fwupd_device_get_property;
+	object_class->set_property = fwupd_device_set_property;
+
+	pspec = g_param_spec_uint ("version-format", NULL, NULL,
+				   FWUPD_VERSION_FORMAT_UNKNOWN,
+				   FWUPD_VERSION_FORMAT_LAST,
+				   FWUPD_VERSION_FORMAT_UNKNOWN,
+				   G_PARAM_READWRITE |
+				   G_PARAM_STATIC_NAME);
+	g_object_class_install_property (object_class, PROP_VERSION_FORMAT, pspec);
 }
 
 static void
@@ -1868,30 +1968,30 @@ fwupd_device_set_from_variant_iter (FwupdDevice *device, GVariantIter *iter)
 
 /**
  * fwupd_device_from_variant:
- * @data: a #GVariant
+ * @value: a #GVariant
  *
  * Creates a new device using packed data.
  *
- * Returns: (transfer full): a new #FwupdDevice, or %NULL if @data was invalid
+ * Returns: (transfer full): a new #FwupdDevice, or %NULL if @value was invalid
  *
  * Since: 1.0.0
  **/
 FwupdDevice *
-fwupd_device_from_variant (GVariant *data)
+fwupd_device_from_variant (GVariant *value)
 {
 	FwupdDevice *dev = NULL;
 	const gchar *type_string;
 	g_autoptr(GVariantIter) iter = NULL;
 
 	/* format from GetDetails */
-	type_string = g_variant_get_type_string (data);
+	type_string = g_variant_get_type_string (value);
 	if (g_strcmp0 (type_string, "(a{sv})") == 0) {
 		dev = fwupd_device_new ();
-		g_variant_get (data, "(a{sv})", &iter);
+		g_variant_get (value, "(a{sv})", &iter);
 		fwupd_device_set_from_variant_iter (dev, iter);
 	} else if (g_strcmp0 (type_string, "a{sv}") == 0) {
 		dev = fwupd_device_new ();
-		g_variant_get (data, "a{sv}", &iter);
+		g_variant_get (value, "a{sv}", &iter);
 		fwupd_device_set_from_variant_iter (dev, iter);
 	} else {
 		g_warning ("type %s not known", type_string);
@@ -1899,6 +1999,57 @@ fwupd_device_from_variant (GVariant *data)
 	return dev;
 }
 
+/**
+ * fwupd_device_array_from_variant:
+ * @value: a #GVariant
+ *
+ * Creates an array of new devices using packed data.
+ *
+ * Returns: (transfer container) (element-type FwupdDevice): devices, or %NULL if @value was invalid
+ *
+ * Since: 1.2.10
+ **/
+GPtrArray *
+fwupd_device_array_from_variant (GVariant *value)
+{
+	GPtrArray *array = NULL;
+	gsize sz;
+	g_autoptr(GVariant) untuple = NULL;
+	g_autoptr(GHashTable) devices_by_id = NULL;
+
+	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	devices_by_id = g_hash_table_new (g_str_hash, g_str_equal);
+	untuple = g_variant_get_child_value (value, 0);
+	sz = g_variant_n_children (untuple);
+	for (guint i = 0; i < sz; i++) {
+		FwupdDevice *dev;
+		g_autoptr(GVariant) data = NULL;
+		data = g_variant_get_child_value (untuple, i);
+		dev = fwupd_device_from_variant (data);
+		if (dev == NULL)
+			continue;
+		g_ptr_array_add (array, dev);
+		if (fwupd_device_get_id (dev) != NULL) {
+			g_hash_table_insert (devices_by_id,
+					     (gpointer) fwupd_device_get_id (dev),
+					     (gpointer) dev);
+		}
+	}
+
+	/* set the parent on each child */
+	for (guint i = 0; i < array->len; i++) {
+		FwupdDevice *dev = g_ptr_array_index (array, i);
+		const gchar *parent_id = fwupd_device_get_parent_id (dev);
+		if (parent_id != NULL) {
+			FwupdDevice *dev_tmp;
+			dev_tmp = g_hash_table_lookup (devices_by_id, parent_id);
+			fwupd_device_set_parent (dev, dev_tmp);
+		}
+	}
+
+	return array;
+}
+
 /**
  * fwupd_device_compare:
  * @device1: a #FwupdDevice
