@@ -1,26 +1,10 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
+ * Copyright (C) 2015-2018 Richard Hughes <richard@hughsie.com>
  *
- * Copyright (C) 2015-2017 Richard Hughes <richard@hughsie.com>
- *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FWUPD_RELEASE_H
-#define __FWUPD_RELEASE_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -53,9 +37,16 @@ void		 fwupd_release_set_version		(FwupdRelease	*release,
 const gchar	*fwupd_release_get_uri			(FwupdRelease	*release);
 void		 fwupd_release_set_uri			(FwupdRelease	*release,
 							 const gchar	*uri);
+GPtrArray	*fwupd_release_get_categories		(FwupdRelease	*release);
+void		 fwupd_release_add_category		(FwupdRelease	*release,
+							 const gchar	*category);
+gboolean	 fwupd_release_has_category		(FwupdRelease	*release,
+							 const gchar	*category);
 GPtrArray	*fwupd_release_get_checksums		(FwupdRelease	*release);
 void		 fwupd_release_add_checksum		(FwupdRelease	*release,
 							 const gchar	*checksum);
+gboolean	 fwupd_release_has_checksum		(FwupdRelease	*release,
+							 const gchar	*checksum);
 
 GHashTable	*fwupd_release_get_metadata		(FwupdRelease	*release);
 void		 fwupd_release_add_metadata		(FwupdRelease	*release,
@@ -69,6 +60,9 @@ const gchar	*fwupd_release_get_metadata_item	(FwupdRelease	*release,
 const gchar	*fwupd_release_get_filename		(FwupdRelease	*release);
 void		 fwupd_release_set_filename		(FwupdRelease	*release,
 							 const gchar	*filename);
+const gchar	*fwupd_release_get_protocol		(FwupdRelease	*release);
+void		 fwupd_release_set_protocol		(FwupdRelease	*release,
+							 const gchar	*protocol);
 const gchar	*fwupd_release_get_appstream_id		(FwupdRelease	*release);
 void		 fwupd_release_set_appstream_id		(FwupdRelease	*release,
 							 const gchar	*appstream_id);
@@ -90,17 +84,40 @@ void		 fwupd_release_set_description		(FwupdRelease	*release,
 const gchar	*fwupd_release_get_homepage		(FwupdRelease	*release);
 void		 fwupd_release_set_homepage		(FwupdRelease	*release,
 							 const gchar	*homepage);
+const gchar	*fwupd_release_get_details_url		(FwupdRelease	*release);
+void		 fwupd_release_set_details_url		(FwupdRelease	*release,
+							 const gchar	*details_url);
+const gchar	*fwupd_release_get_source_url		(FwupdRelease	*release);
+void		 fwupd_release_set_source_url		(FwupdRelease	*release,
+							 const gchar	*source_url);
 guint64		 fwupd_release_get_size			(FwupdRelease	*release);
 void		 fwupd_release_set_size			(FwupdRelease	*release,
 							 guint64	 size);
 const gchar	*fwupd_release_get_license		(FwupdRelease	*release);
 void		 fwupd_release_set_license		(FwupdRelease	*release,
 							 const gchar	*license);
-FwupdTrustFlags	 fwupd_release_get_trust_flags		(FwupdRelease	*release);
+FwupdTrustFlags	 fwupd_release_get_trust_flags		(FwupdRelease	*release)
+G_DEPRECATED_FOR(fwupd_release_get_flags);
 void		 fwupd_release_set_trust_flags		(FwupdRelease	*release,
-							 FwupdTrustFlags trust_flags);
+							 FwupdTrustFlags trust_flags)
+G_DEPRECATED_FOR(fwupd_release_set_flags);
+FwupdReleaseFlags fwupd_release_get_flags		(FwupdRelease	*release);
+void		 fwupd_release_set_flags		(FwupdRelease	*release,
+							 FwupdReleaseFlags flags);
+void		 fwupd_release_add_flag			(FwupdRelease	*release,
+							 FwupdReleaseFlags flag);
+void		 fwupd_release_remove_flag		(FwupdRelease	*release,
+							 FwupdReleaseFlags flag);
+gboolean	 fwupd_release_has_flag			(FwupdRelease	*release,
+							 FwupdReleaseFlags flag);
+guint32		 fwupd_release_get_install_duration	(FwupdRelease	*release);
+void		 fwupd_release_set_install_duration	(FwupdRelease	*release,
+							 guint32	 duration);
+const gchar	*fwupd_release_get_update_message	(FwupdRelease	*release);
+void		 fwupd_release_set_update_message	(FwupdRelease	*release,
+							 const gchar	*update_message);
+
+FwupdRelease	*fwupd_release_from_variant		(GVariant	*value);
+GPtrArray	*fwupd_release_array_from_variant	(GVariant	*value);
 
 G_END_DECLS
-
-#endif /* __FWUPD_RELEASE_H */
-
