@@ -1212,30 +1212,30 @@ fwupd_remote_finalize (GObject *obj)
 
 /**
  * fwupd_remote_from_variant:
- * @data: a #GVariant
+ * @value: a #GVariant
  *
  * Creates a new remote using packed data.
  *
- * Returns: (transfer full): a new #FwupdRemote, or %NULL if @data was invalid
+ * Returns: (transfer full): a new #FwupdRemote, or %NULL if @value was invalid
  *
  * Since: 1.0.0
  **/
 FwupdRemote *
-fwupd_remote_from_variant (GVariant *data)
+fwupd_remote_from_variant (GVariant *value)
 {
 	FwupdRemote *rel = NULL;
 	const gchar *type_string;
 	g_autoptr(GVariantIter) iter = NULL;
 
-	type_string = g_variant_get_type_string (data);
+	type_string = g_variant_get_type_string (value);
 	if (g_strcmp0 (type_string, "(a{sv})") == 0) {
 		rel = fwupd_remote_new ();
-		g_variant_get (data, "(a{sv})", &iter);
+		g_variant_get (value, "(a{sv})", &iter);
 		fwupd_remote_set_from_variant_iter (rel, iter);
 		fwupd_remote_set_from_variant_iter (rel, iter);
 	} else if (g_strcmp0 (type_string, "a{sv}") == 0) {
 		rel = fwupd_remote_new ();
-		g_variant_get (data, "a{sv}", &iter);
+		g_variant_get (value, "a{sv}", &iter);
 		fwupd_remote_set_from_variant_iter (rel, iter);
 	} else {
 		g_warning ("type %s not known", type_string);
@@ -1243,6 +1243,35 @@ fwupd_remote_from_variant (GVariant *data)
 	return rel;
 }
 
+/**
+ * fwupd_remote_array_from_variant:
+ * @value: a #GVariant
+ *
+ * Creates an array of new devices using packed data.
+ *
+ * Returns: (transfer container) (element-type FwupdRemote): remotes, or %NULL if @value was invalid
+ *
+ * Since: 1.2.10
+ **/
+GPtrArray *
+fwupd_remote_array_from_variant (GVariant *value)
+{
+	GPtrArray *remotes = NULL;
+	gsize sz;
+	g_autoptr(GVariant) untuple = NULL;
+
+	remotes = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	untuple = g_variant_get_child_value (value, 0);
+	sz = g_variant_n_children (untuple);
+	for (guint i = 0; i < sz; i++) {
+		g_autoptr(GVariant) data = g_variant_get_child_value (untuple, i);
+		FwupdRemote *remote = fwupd_remote_from_variant (data);
+		g_ptr_array_add (remotes, remote);
+	}
+
+	return remotes;
+}
+
 /**
  * fwupd_remote_new:
  *
