@@ -1,26 +1,10 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
+/*
  * Copyright (C) 2017-2018 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FWUPD_REMOTE_H
-#define __FWUPD_REMOTE_H
+#pragma once
 
 #include "fwupd-enums.h"
 
@@ -42,10 +26,20 @@ struct _FwupdRemoteClass
 	void (*_fwupd_reserved7)	(void);
 };
 
+/**
+ * FwupdRemoteKind:
+ * @FWUPD_REMOTE_KIND_UNKNOWN:			Unknown kind
+ * @FWUPD_REMOTE_KIND_DOWNLOAD:			Requires files to be downloaded
+ * @FWUPD_REMOTE_KIND_LOCAL:			Reads files from the local machine
+ * @FWUPD_REMOTE_KIND_DIRECTORY:		Reads directory from the local machine
+ *
+ * The kind of remote.
+ **/
 typedef enum {
 	FWUPD_REMOTE_KIND_UNKNOWN,
 	FWUPD_REMOTE_KIND_DOWNLOAD,
 	FWUPD_REMOTE_KIND_LOCAL,
+	FWUPD_REMOTE_KIND_DIRECTORY,			/* Since: 1.2.4 */
 	/*< private >*/
 	FWUPD_REMOTE_KIND_LAST
 } FwupdRemoteKind;
@@ -56,6 +50,7 @@ const gchar	*fwupd_remote_kind_to_string		(FwupdRemoteKind kind);
 FwupdRemote	*fwupd_remote_new			(void);
 const gchar	*fwupd_remote_get_id			(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_title			(FwupdRemote	*self);
+const gchar	*fwupd_remote_get_agreement		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_checksum		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_username		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_password		(FwupdRemote	*self);
@@ -67,6 +62,7 @@ const gchar	*fwupd_remote_get_report_uri		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_metadata_uri		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_metadata_uri_sig	(FwupdRemote	*self);
 gboolean	 fwupd_remote_get_enabled		(FwupdRemote	*self);
+gboolean	 fwupd_remote_get_approval_required	(FwupdRemote	*self);
 gint		 fwupd_remote_get_priority		(FwupdRemote	*self);
 guint64		 fwupd_remote_get_age			(FwupdRemote	*self);
 FwupdRemoteKind	 fwupd_remote_get_kind			(FwupdRemote	*self);
@@ -75,7 +71,7 @@ gchar		*fwupd_remote_build_firmware_uri	(FwupdRemote	*self,
 							 const gchar	*url,
 							 GError		**error);
 
+FwupdRemote	*fwupd_remote_from_variant		(GVariant	*value);
+GPtrArray	*fwupd_remote_array_from_variant	(GVariant	*value);
+
 G_END_DECLS
-
-#endif /* __FWUPD_REMOTE_H */
-
