@@ -36,6 +36,7 @@ struct ata_tf {
 #define ATA_STAT_ERR			(1 << 0)
 
 #define ATA_OP_IDENTIFY			0xec
+#define ATA_OP_FLUSH_CACHE		0xe7
 #define ATA_OP_DOWNLOAD_MICROCODE	0x92
 #define ATA_OP_STANDBY_IMMEDIATE	0xe0
 
@@ -242,17 +243,22 @@ fu_ata_device_parse_id (FuAtaDevice *self, const guint8 *buf, gsize sz, GError *
 	if (fu_device_get_serial (device) == NULL) {
 		g_autofree gchar *tmp = NULL;
 		tmp = fu_ata_device_get_string (id, 10, 19);
-		fu_device_set_serial (device, tmp);
+		if (tmp != NULL)
+			fu_device_set_serial (device, tmp);
 	}
 	if (fu_device_get_name (device) == NULL) {
 		g_autofree gchar *tmp = NULL;
 		tmp = fu_ata_device_get_string (id, 27, 46);
-		fu_device_set_name (device, tmp);
+		if (tmp != NULL)
+			fu_device_set_name (device, tmp);
 	}
 	if (fu_device_get_version (device) == NULL) {
 		g_autofree gchar *tmp = NULL;
 		tmp = fu_ata_device_get_string (id, 23, 26);
-		fu_device_set_version (device, tmp);
+		if (tmp != NULL)
+			fu_device_set_version (device, tmp, FWUPD_VERSION_FORMAT_PLAIN);
+	} else {
+		fu_device_set_version_format (device, FWUPD_VERSION_FORMAT_PLAIN);
 	}
 
 	/* 8 byte additional product identifier == SKU? */
@@ -473,10 +479,18 @@ fu_ata_device_activate (FuDevice *device, GError **error)
 	FuAtaDevice *self = FU_ATA_DEVICE (device);
 	struct ata_tf tf = { 0x0 };
 
-	/* flush caches and make sure drive is ready to activate */
-	tf.dev = 0xa0 | ATA_USING_LBA;
+
+	/* flush cache and put drive in standby to prepare to activate */
+	tf.dev = ATA_USING_LBA;
+	tf.command = ATA_OP_FLUSH_CACHE;
+	if (!fu_ata_device_command (self, &tf, SG_DXFER_NONE,
+				    120 * 1000, /* a long time! */
+				    NULL, 0, error)) {
+		g_prefix_error (error, "failed to flush cache immediate: ");
+		return FALSE;
+	}
 	tf.command = ATA_OP_STANDBY_IMMEDIATE;
-	if (!fu_ata_device_command (self, &tf, SG_DXFER_TO_DEV,
+	if (!fu_ata_device_command (self, &tf, SG_DXFER_NONE,
 				    120 * 1000, /* a long time! */
 				    NULL, 0, error)) {
 		g_prefix_error (error, "failed to standby immediate: ");
@@ -484,9 +498,10 @@ fu_ata_device_activate (FuDevice *device, GError **error)
 	}
 
 	/* load the new firmware */
+	tf.dev = 0xa0 | ATA_USING_LBA;
 	tf.command = ATA_OP_DOWNLOAD_MICROCODE;
 	tf.feat = ATA_SUBCMD_MICROCODE_ACTIVATE;
-	if (!fu_ata_device_command (self, &tf, SG_DXFER_TO_DEV,
+	if (!fu_ata_device_command (self, &tf, SG_DXFER_NONE,
 				    120 * 1000, /* a long time! */
 				    NULL, 0, error)) {
 		g_prefix_error (error, "failed to activate firmware: ");
@@ -562,7 +577,10 @@ fu_ata_device_fw_download (FuAtaDevice *self,
 }
 
 static gboolean
-fu_ata_device_write_firmware (FuDevice *device, GBytes *fw, GError **error)
+fu_ata_device_write_firmware (FuDevice *device,
+			      GBytes *fw,
+			      FwupdInstallFlags flags,
+			      GError **error)
 {
 	FuAtaDevice *self = FU_ATA_DEVICE (device);
 	guint32 chunksz = (guint32) self->transfer_blocks * FU_ATA_BLOCK_SIZE;
