@@ -47,6 +47,7 @@ fu_dell_dock_hub_probe (FuDevice *device, GError **error)
 static gboolean
 fu_dell_dock_hub_write_fw (FuDevice *device,
 			   GBytes *blob_fw,
+			   FwupdInstallFlags flags,
 			   GError **error)
 {
 	FuDellDockHub *self = FU_DELL_DOCK_HUB (device);
@@ -102,8 +103,7 @@ fu_dell_dock_hub_write_fw (FuDevice *device,
 	}
 
 	/* dock will reboot to re-read; this is to appease the daemon */
-	fu_device_set_version (device, dynamic_version);
-
+	fu_device_set_version (device, dynamic_version, FWUPD_VERSION_FORMAT_PAIR);
 	return TRUE;
 }
 
