@@ -54,6 +54,7 @@ G_DEFINE_TYPE (FuDellDockTbt, fu_dell_dock_tbt, FU_TYPE_DEVICE)
 static gboolean
 fu_dell_dock_tbt_write_fw (FuDevice *device,
 			   GBytes *blob_fw,
+			   FwupdInstallFlags flags,
 			   GError **error)
 {
 	FuDellDockTbt *self = FU_DELL_DOCK_TBT (device);
@@ -128,7 +129,7 @@ fu_dell_dock_tbt_write_fw (FuDevice *device,
 	}
 
 	/* dock will reboot to re-read; this is to appease the daemon */
-	fu_device_set_version (device, dynamic_version);
+	fu_device_set_version (device, dynamic_version, FWUPD_VERSION_FORMAT_PAIR);
 
 	return TRUE;
 }
@@ -186,9 +187,8 @@ fu_dell_dock_tbt_setup (FuDevice *device, GError **error)
 	/* set version from EC if we know it */
 	parent = fu_device_get_parent (device);
 	version = fu_dell_dock_ec_get_tbt_version (parent);
-
 	if (version != NULL)
-		fu_device_set_version (device, version);
+		fu_device_set_version (device, version, FWUPD_VERSION_FORMAT_PAIR);
 
 	/* minimum version of NVM that supports this feature */
 	if (version == NULL || fu_common_vercmp (version, MIN_NVM) < 0) {
