@@ -15,8 +15,12 @@
 #include "fu-mm-utils.h"
 #include "fu-qmi-pdc-updater.h"
 
-/* amount of time for the modem to be re-probed and exposed in MM after being uninhibited */
-#define FU_MM_DEVICE_REMOVE_DELAY_REPROBE	45000	/* ms */
+/* Amount of time for the modem to be re-probed and exposed in MM after being
+ * uninhibited. The timeout is long enough to cover the worst case, where the
+ * modem boots without SIM card inserted (and therefore the initialization
+ * may be very slow) and also where carrier config switching is explicitly
+ * required (e.g. if switching from the default (DF) to generic (GC).*/
+#define FU_MM_DEVICE_REMOVE_DELAY_REPROBE	120000	/* ms */
 
 struct _FuMmDevice {
 	FuDevice			 parent_instance;
@@ -44,8 +48,17 @@ struct _FuMmDevice {
 	/* qmi-pdc update logic */
 	gchar				*port_qmi;
 	FuQmiPdcUpdater			*qmi_pdc_updater;
+	GArray				*qmi_pdc_active_id;
+	guint				 attach_idle;
 };
 
+enum {
+	SIGNAL_ATTACH_FINISHED,
+	SIGNAL_LAST
+};
+
+static guint signals [SIGNAL_LAST] = { 0 };
+
 G_DEFINE_TYPE (FuMmDevice, fu_mm_device, FU_TYPE_DEVICE)
 
 static void
@@ -221,9 +234,11 @@ fu_mm_device_probe_default (FuDevice *device, GError **error)
 
 	/* add properties to fwupd device */
 	fu_device_set_physical_id (device, device_sysfs_path);
-	fu_device_set_vendor (device, mm_modem_get_manufacturer (modem));
-	fu_device_set_name (device, mm_modem_get_model (modem));
-	fu_device_set_version (device, version);
+	if (mm_modem_get_manufacturer (modem) != NULL)
+		fu_device_set_vendor (device, mm_modem_get_manufacturer (modem));
+	if (mm_modem_get_model (modem) != NULL)
+		fu_device_set_name (device, mm_modem_get_model (modem));
+	fu_device_set_version (device, version, FWUPD_VERSION_FORMAT_UNKNOWN);
 	for (guint i = 0; device_ids[i] != NULL; i++)
 		fu_device_add_instance_id (device, device_ids[i]);
 
@@ -422,13 +437,16 @@ fu_mm_device_detach (FuDevice *device, GError **error)
 }
 
 typedef struct {
-	gchar  *filename;
-	GBytes *bytes;
+	gchar		*filename;
+	GBytes		*bytes;
+	GArray		*digest;
+	gboolean	 active;
 } FuMmFileInfo;
 
 static void
 fu_mm_file_info_free (FuMmFileInfo *file_info)
 {
+	g_clear_pointer (&file_info->digest, g_array_unref);
 	g_free (file_info->filename);
 	g_bytes_unref (file_info->bytes);
 	g_free (file_info);
@@ -442,6 +460,34 @@ typedef struct {
 	gsize		 total_bytes;
 } FuMmArchiveIterateCtx;
 
+static gboolean
+fu_mm_should_be_active (const gchar *version,
+			const gchar *filename)
+{
+	g_auto(GStrv) split = NULL;
+	g_autofree gchar *carrier_id = NULL;
+
+	/* The filename of the mcfg file is composed of a "mcfg." prefix, then the
+	 * carrier code, followed by the carrier version, and finally a ".mbn"
+	 * prefix. Here we try to guess, based on the carrier code, whether the
+	 * specific mcfg file should be activated after the firmware upgrade
+	 * operation.
+	 *
+	 * This logic requires that the previous device version includes the carrier
+	 * code also embedded in the version string. E.g. "xxxx.VF.xxxx". If we find
+	 * this match, we assume this is the active config to use.
+	 */
+
+	split = g_strsplit (filename, ".", -1);
+	if (g_strv_length (split) < 4)
+		return FALSE;
+	if (g_strcmp0 (split[0], "mcfg") != 0)
+		return FALSE;
+
+	carrier_id = g_strdup_printf (".%s.", split[1]);
+	return (g_strstr_len (version, -1, carrier_id) != NULL);
+}
+
 static void
 fu_mm_qmi_pdc_archive_iterate_mcfg (FuArchive	*archive,
 				    const gchar	*filename,
@@ -458,6 +504,7 @@ fu_mm_qmi_pdc_archive_iterate_mcfg (FuArchive	*archive,
 	file_info = g_new0 (FuMmFileInfo, 1);
 	file_info->filename = g_strdup (filename);
 	file_info->bytes = g_bytes_ref (bytes);
+	file_info->active = fu_mm_should_be_active (fu_device_get_version (FU_DEVICE (ctx->device)), filename);
 	g_ptr_array_add (ctx->file_infos, file_info);
 	ctx->total_bytes += g_bytes_get_size (file_info->bytes);
 }
@@ -479,11 +526,22 @@ fu_mm_device_qmi_close (FuMmDevice *self, GError **error)
 }
 
 static gboolean
-fu_mm_device_write_firmware_qmi_pdc (FuDevice *device, GBytes *fw, GError **error)
+fu_mm_device_qmi_close_no_error (FuMmDevice *self, GError **error)
+{
+	g_autoptr(FuQmiPdcUpdater) updater = NULL;
+
+	updater = g_steal_pointer (&self->qmi_pdc_updater);
+	fu_qmi_pdc_updater_close (updater, NULL);
+	return TRUE;
+}
+
+static gboolean
+fu_mm_device_write_firmware_qmi_pdc (FuDevice *device, GBytes *fw, GArray **active_id, GError **error)
 {
 	g_autoptr(FuArchive) archive = NULL;
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	g_autoptr(GPtrArray) file_infos = g_ptr_array_new_with_free_func ((GDestroyNotify)fu_mm_file_info_free);
+	gint active_i = -1;
 	FuMmArchiveIterateCtx archive_context = {
 		.device = FU_MM_DEVICE (device),
 		.error = NULL,
@@ -510,14 +568,26 @@ fu_mm_device_write_firmware_qmi_pdc (FuDevice *device, GBytes *fw, GError **erro
 
 	for (guint i = 0; i < file_infos->len; i++) {
 		FuMmFileInfo *file_info = g_ptr_array_index (file_infos, i);
-		if (!fu_qmi_pdc_updater_write (archive_context.device->qmi_pdc_updater,
-					       file_info->filename,
-					       file_info->bytes,
-					       &archive_context.error)) {
+		file_info->digest = fu_qmi_pdc_updater_write (archive_context.device->qmi_pdc_updater,
+							      file_info->filename,
+							      file_info->bytes,
+							      &archive_context.error);
+		if (file_info->digest == NULL) {
 			g_prefix_error (&archive_context.error,
 					"Failed to write file '%s':", file_info->filename);
 			break;
 		}
+		/* if we wrongly detect more than one, just assume the latest one; this
+		 * is not critical, it may just take a bit more time to perform the
+		 * automatic carrier config switching in ModemManager */
+		if (file_info->active)
+			active_i = i;
+	}
+
+	/* set expected active configuration */
+	if (active_i >= 0 && active_id != NULL) {
+		FuMmFileInfo *file_info = g_ptr_array_index (file_infos, active_i);
+		*active_id = g_array_ref (file_info->digest);
 	}
 
 	if (archive_context.error != NULL) {
@@ -529,7 +599,10 @@ fu_mm_device_write_firmware_qmi_pdc (FuDevice *device, GBytes *fw, GError **erro
 }
 
 static gboolean
-fu_mm_device_write_firmware (FuDevice *device, GBytes *fw, GError **error)
+fu_mm_device_write_firmware (FuDevice *device,
+			     GBytes *fw,
+			     FwupdInstallFlags flags,
+			     GError **error)
 {
 	FuMmDevice *self = FU_MM_DEVICE (device);
 	g_autoptr(FuDeviceLocker) locker = NULL;
@@ -543,16 +616,65 @@ fu_mm_device_write_firmware (FuDevice *device, GBytes *fw, GError **error)
 
 	/* qmi pdc write operation */
 	if (self->update_methods & MM_MODEM_FIRMWARE_UPDATE_METHOD_QMI_PDC)
-		return fu_mm_device_write_firmware_qmi_pdc (device, fw, error);
+		return fu_mm_device_write_firmware_qmi_pdc (device, fw, &self->qmi_pdc_active_id, error);
 
 	g_set_error (error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED,
 		     "unsupported update method");
 	return FALSE;
 }
 
+static gboolean
+fu_mm_device_attach_qmi_pdc (FuMmDevice *self, GError **error)
+{
+	g_autoptr(FuDeviceLocker) locker = NULL;
+
+	/* ignore action if there is no active id specified */
+	if (self->qmi_pdc_active_id == NULL)
+		return TRUE;
+
+	/* errors closing may be expected if the device really reboots itself */
+	locker = fu_device_locker_new_full (self,
+					    (FuDeviceLockerFunc) fu_mm_device_qmi_open,
+					    (FuDeviceLockerFunc) fu_mm_device_qmi_close_no_error,
+					    error);
+	if (locker == NULL)
+		return FALSE;
+
+	if (!fu_qmi_pdc_updater_activate (self->qmi_pdc_updater, self->qmi_pdc_active_id, error))
+		return FALSE;
+
+	return TRUE;
+}
+
+static gboolean
+fu_mm_device_attach_noop_idle (gpointer user_data)
+{
+	FuMmDevice *self = FU_MM_DEVICE (user_data);
+	self->attach_idle = 0;
+	g_signal_emit (self, signals [SIGNAL_ATTACH_FINISHED], 0);
+	return G_SOURCE_REMOVE;
+}
+
+static gboolean
+fu_mm_device_attach_qmi_pdc_idle (gpointer user_data)
+{
+	FuMmDevice *self = FU_MM_DEVICE (user_data);
+	g_autoptr(GError) error = NULL;
+
+	if (!fu_mm_device_attach_qmi_pdc (self, &error))
+		g_warning ("qmi-pdc attach operation failed: %s", error->message);
+	else
+		g_debug ("qmi-pdc attach operation successful");
+
+	self->attach_idle = 0;
+	g_signal_emit (self, signals [SIGNAL_ATTACH_FINISHED], 0);
+	return G_SOURCE_REMOVE;
+}
+
 static gboolean
 fu_mm_device_attach (FuDevice *device, GError **error)
 {
+	FuMmDevice *self = FU_MM_DEVICE (device);
 	g_autoptr(FuDeviceLocker) locker  = NULL;
 
 	/* lock device */
@@ -560,6 +682,13 @@ fu_mm_device_attach (FuDevice *device, GError **error)
 	if (locker == NULL)
 		return FALSE;
 
+	/* we want this attach operation to be triggered asynchronously, because the engine
+	 * must learn that it has to wait for replug before we actually trigger the reset. */
+	if (self->update_methods & MM_MODEM_FIRMWARE_UPDATE_METHOD_QMI_PDC)
+		self->attach_idle = g_idle_add ((GSourceFunc) fu_mm_device_attach_qmi_pdc_idle, self);
+	else
+		self->attach_idle = g_idle_add ((GSourceFunc) fu_mm_device_attach_noop_idle, self);
+
 	/* wait for re-probing after uninhibiting */
 	fu_device_set_remove_delay (device, FU_MM_DEVICE_REMOVE_DELAY_REPROBE);
 	fu_device_add_flag (device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
@@ -579,6 +708,10 @@ static void
 fu_mm_device_finalize (GObject *object)
 {
 	FuMmDevice *self = FU_MM_DEVICE (object);
+	if (self->attach_idle)
+		g_source_remove (self->attach_idle);
+	if (self->qmi_pdc_active_id)
+		g_array_unref (self->qmi_pdc_active_id);
 	g_object_unref (self->manager);
 	if (self->omodem != NULL)
 		g_object_unref (self->omodem);
@@ -600,6 +733,12 @@ fu_mm_device_class_init (FuMmDeviceClass *klass)
 	klass_device->detach = fu_mm_device_detach;
 	klass_device->write_firmware = fu_mm_device_write_firmware;
 	klass_device->attach = fu_mm_device_attach;
+
+	signals [SIGNAL_ATTACH_FINISHED] =
+		g_signal_new ("attach-finished",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 }
 
 FuMmDevice *
@@ -655,7 +794,7 @@ fu_mm_device_udev_new (MMManager *manager,
 	fu_device_set_physical_id (FU_DEVICE (self), info->physical_id);
 	fu_device_set_vendor (FU_DEVICE (self), info->vendor);
 	fu_device_set_name (FU_DEVICE (self), info->name);
-	fu_device_set_version (FU_DEVICE (self), info->version);
+	fu_device_set_version (FU_DEVICE (self), info->version, FWUPD_VERSION_FORMAT_UNKNOWN);
 	self->update_methods = info->update_methods;
 	self->detach_fastboot_at = g_strdup (info->detach_fastboot_at);
 	self->port_at_ifnum = info->port_at_ifnum;
