@@ -187,5 +187,5 @@ fu_plugin_update (FuPlugin *plugin,
 	locker = fu_device_locker_new (device, error);
 	if (locker == NULL)
 		return FALSE;
-	return fu_device_write_firmware (device, blob_fw, error);
+	return fu_device_write_firmware (device, blob_fw, flags, error);
 }
