@@ -15,6 +15,30 @@
 #define SYNAPTICS_FLASH_MODE_DELAY 3
 #define SYNAPTICS_UPDATE_ENUMERATE_TRIES 3
 
+static gboolean
+syanpticsmst_check_amdgpu_safe (GError **error)
+{
+	gsize bufsz = 0;
+	g_autofree gchar *buf = NULL;
+	g_auto(GStrv) lines = NULL;
+
+	if (!g_file_get_contents ("/proc/modules", &buf, &bufsz, error))
+		return FALSE;
+
+	lines = g_strsplit (buf, "\n", -1);
+	for (guint i = 0; lines[i] != NULL; i++) {
+		if (g_str_has_prefix (lines[i], "amdgpu ")) {
+			g_set_error_literal (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_INTERNAL,
+					     "amdgpu has known issues with synapticsmst");
+			return FALSE;
+		}
+	}
+
+	return TRUE;
+}
+
 static gboolean
 synapticsmst_common_check_supported_system (FuPlugin *plugin, GError **error)
 {
@@ -24,6 +48,10 @@ synapticsmst_common_check_supported_system (FuPlugin *plugin, GError **error)
 		return TRUE;
 	}
 
+	/* See https://github.com/hughsie/fwupd/issues/1121 for more details */
+	if (!syanpticsmst_check_amdgpu_safe (error))
+		return FALSE;
+
 	if (!g_file_test (SYSFS_DRM_DP_AUX, G_FILE_TEST_IS_DIR)) {
 		g_set_error (error,
 			     G_IO_ERROR,
@@ -161,13 +189,15 @@ fu_plugin_synaptics_add_device (FuPlugin *plugin,
 	fu_device_set_vendor (dev, "Synaptics");
 	fu_device_set_summary (dev, "Multi-Stream Transport Device");
 	fu_device_add_icon (dev, "computer");
-	fu_device_set_version (dev, synapticsmst_device_get_version (device));
+	fu_device_set_version (dev, synapticsmst_device_get_version (device),
+			       FWUPD_VERSION_FORMAT_TRIPLET);
 	fu_device_set_quirks (dev, fu_plugin_get_quirks (plugin));
 
 	/* create GUIDs and name */
 	if (!fu_plugin_synapticsmst_lookup_device (plugin, dev, device, error))
 		return FALSE;
-
+	if (!fu_device_setup (dev, error))
+		return FALSE;
 	fu_plugin_device_add (plugin, dev);
 	fu_plugin_cache_add (plugin, dev_id_str, dev);
 
@@ -289,7 +319,7 @@ fu_plugin_synapticsmst_enumerate (FuPlugin *plugin,
 		dev_id_str = g_strdup_printf ("MST-DIRECT-%s-0-0", aux_node);
 		fu_dev = fu_plugin_cache_lookup (plugin, dev_id_str);
 
-		/* If we open succesfully a device exists here */
+		/* If we open successfully a device exists here */
 		device = synapticsmst_device_new (SYNAPTICSMST_DEVICE_KIND_DIRECT, aux_node, 0, 0);
 		if (!synapticsmst_device_open (device, &error_local)) {
 			/* No device exists here, but was there - remove from DB */
@@ -401,7 +431,8 @@ fu_plugin_update (FuPlugin *plugin,
 			}
 		}
 	}
-	fu_device_set_version (dev, synapticsmst_device_get_version (device));
+	fu_device_set_version (dev, synapticsmst_device_get_version (device),
+			       FWUPD_VERSION_FORMAT_TRIPLET);
 
 	return TRUE;
 }
