@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __SYNAPTICSMST_COMMON_H
-#define __SYNAPTICSMST_COMMON_H
+#pragma once
 
 #include <glib.h>
 #include <gio/gio.h>
@@ -14,6 +13,9 @@
 #define ADDR_CUSTOMER_ID	0X10E
 #define ADDR_BOARD_ID		0x10F
 
+#define ADDR_MEMORY_CUSTOMER_ID	0x170E
+#define ADDR_MEMORY_BOARD_ID	0x170F
+
 #define REG_RC_CAP		0x4B0
 #define REG_RC_STATE		0X4B1
 #define REG_RC_CMD		0x4B2
@@ -105,5 +107,3 @@ gboolean	 synapticsmst_common_disable_remote_control	(SynapticsMSTConnection *co
 #pragma clang diagnostic ignored "-Wunused-function"
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(SynapticsMSTConnection, synapticsmst_common_free)
 #pragma clang diagnostic pop
-
-#endif /* __SYNAPTICSMST_COMMON_H */
