@@ -255,6 +255,7 @@ fu_plugin_thunderbolt_add (FuPlugin *plugin, GUdevDevice *device)
 	g_autoptr(FuDevice) dev = NULL;
 	g_autoptr(GError) error_vid = NULL;
 	g_autoptr(GError) error_did = NULL;
+	g_autoptr(GError) error_setup = NULL;
 
 	uuid = g_udev_device_get_sysfs_attr (device, "unique_id");
 	if (uuid == NULL) {
@@ -371,12 +372,16 @@ fu_plugin_thunderbolt_add (FuPlugin *plugin, GUdevDevice *device)
 	if (device_id != NULL)
 		fu_device_add_instance_id (dev, device_id);
 	if (version != NULL)
-		fu_device_set_version (dev, version);
+		fu_device_set_version (dev, version, FWUPD_VERSION_FORMAT_PAIR);
 	if (is_host)
 		fu_device_add_flag (dev, FWUPD_DEVICE_FLAG_INTERNAL);
+	fu_device_add_flag (dev, FWUPD_DEVICE_FLAG_REQUIRE_AC);
 
 	/* we never open the device, so convert the instance IDs */
-	fu_device_setup (dev, NULL);
+	if (!fu_device_setup (dev, &error_setup)) {
+		g_warning ("failed to setup: %s", error_setup->message);
+		return;
+	}
 	fu_plugin_cache_add (plugin, id, dev);
 	fu_plugin_device_add (plugin, dev);
 
@@ -426,7 +431,7 @@ fu_plugin_thunderbolt_change (FuPlugin *plugin, GUdevDevice *device)
 	}
 
 	version = fu_plugin_thunderbolt_udev_get_version (device);
-	fu_device_set_version (dev, version);
+	fu_device_set_version (dev, version, FWUPD_VERSION_FORMAT_PAIR);
 }
 
 static gboolean
@@ -502,7 +507,7 @@ fu_plugin_thunderbolt_trigger_update (GUdevDevice  *udevice,
 		if (n < 1 && errno != EINTR) {
 			g_set_error (error, G_IO_ERROR,
 				     g_io_error_from_errno (errno),
-				     "could write to 'nvm_authenticate': %s",
+				     "could not write to 'nvm_authenticate': %s",
 				     g_strerror (errno));
 			(void) close (fd);
 			return FALSE;
@@ -513,7 +518,7 @@ fu_plugin_thunderbolt_trigger_update (GUdevDevice  *udevice,
 	if (r < 0 && errno != EINTR) {
 		g_set_error (error, G_IO_ERROR,
 			     g_io_error_from_errno (errno),
-			     "could close 'nvm_authenticate': %s",
+			     "could not close 'nvm_authenticate': %s",
 			     g_strerror (errno));
 		return FALSE;
 	}
