@@ -24,7 +24,6 @@
 #include <locale.h>
 
 #include "fu-plugin-private.h"
-#include "fu-plugin-thunderbolt.h"
 #include "fu-thunderbolt-image.h"
 #include "fu-test.h"
 
@@ -1046,40 +1045,40 @@ test_image_validation (ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull (bad_data);
 
 	/* now for some testing ... this should work */
-	val = fu_plugin_thunderbolt_validate_image (ctl_data, fwi_data, &error);
+	val = fu_thunderbolt_image_validate (ctl_data, fwi_data, &error);
 	g_assert_no_error (error);
 	g_assert_cmpint (val, ==, VALIDATION_PASSED);
 
 
 	/* these all should fail */
 	/*  valid controller, bad update data */
-	val = fu_plugin_thunderbolt_validate_image (ctl_data, ctl_data, &error);
+	val = fu_thunderbolt_image_validate (ctl_data, ctl_data, &error);
 	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_READ);
 	g_assert_cmpint (val, ==, VALIDATION_FAILED);
 	g_debug ("expected image validation error [ctl, ctl]: %s", error->message);
 	g_clear_error (&error);
 
-	val = fu_plugin_thunderbolt_validate_image (ctl_data, bad_data, &error);
+	val = fu_thunderbolt_image_validate (ctl_data, bad_data, &error);
 	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_READ);
 	g_assert_cmpint (val, ==, VALIDATION_FAILED);
 	g_debug ("expected image validation error [ctl, bad]: %s", error->message);
 	g_clear_error (&error);
 
 	/* bad controller data, valid update data */
-	val = fu_plugin_thunderbolt_validate_image (fwi_data, fwi_data, &error);
+	val = fu_thunderbolt_image_validate (fwi_data, fwi_data, &error);
 	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE);
 	g_assert_cmpint (val, ==, VALIDATION_FAILED);
 	g_debug ("expected image validation error [fwi, fwi]: %s", error->message);
 	g_clear_error (&error);
 
-	val = fu_plugin_thunderbolt_validate_image (bad_data, fwi_data, &error);
+	val = fu_thunderbolt_image_validate (bad_data, fwi_data, &error);
 	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE);
 	g_assert_cmpint (val, ==, VALIDATION_FAILED);
 	g_debug ("expected image validation error [bad, fwi]: %s", error->message);
 	g_clear_error (&error);
 
 	/* both bad */
-	val = fu_plugin_thunderbolt_validate_image (bad_data, bad_data, &error);
+	val = fu_thunderbolt_image_validate (bad_data, bad_data, &error);
 	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_READ);
 	g_assert_cmpint (val, ==, VALIDATION_FAILED);
 	g_debug ("expected image validation error [bad, bad]: %s", error->message);
@@ -1132,7 +1131,16 @@ test_update_working (ThunderboltTest *tt, gconstpointer user_data)
 	/* simulate an update, where the device goes away and comes back
 	 * after the time in the last parameter (given in ms) */
 	up_ctx = mock_tree_prepare_for_update (tree, plugin, "42.23", fw_data, 1000);
-	ret = fu_plugin_runner_update (plugin, tree->fu_device, NULL, fw_data, 0, &error);
+	ret = fu_plugin_runner_update (plugin, tree->fu_device, fw_data, 0, &error);
+	g_assert_no_error (error);
+	g_assert_true (ret);
+
+	/* we wait until the plugin has picked up  all the
+	 * subtree changes */
+	ret = mock_tree_settle (tree, plugin);
+	g_assert_true (ret);
+
+	ret = fu_plugin_runner_update_attach (plugin, tree->fu_device, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
 
@@ -1140,8 +1148,7 @@ test_update_working (ThunderboltTest *tt, gconstpointer user_data)
 	g_debug ("version after update: %s", version_after);
 	g_assert_cmpstr (version_after, ==, "42.23");
 
-	/* we wait until the plugin has picked up  all the
-	 * subtree changes */
+	/* make sure all pending events have happened */
 	ret = mock_tree_settle (tree, plugin);
 	g_assert_true (ret);
 
@@ -1173,14 +1180,9 @@ test_update_fail (ThunderboltTest *tt, gconstpointer user_data)
 	up_ctx = mock_tree_prepare_for_update (tree, plugin, "42.23", fw_data, 1000);
 	up_ctx->result = UPDATE_FAIL_DEVICE_INTERNAL;
 
-	ret = fu_plugin_runner_update (plugin, tree->fu_device, NULL, fw_data, 0, &error);
-	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL);
-	g_assert_false (ret);
-
-	/* version should *not* have changed (but we get parsed version) */
-	version_after = fu_device_get_version (tree->fu_device);
-	g_debug ("version after update: %s", version_after);
-	g_assert_cmpstr (version_after, ==, tree->device->nvm_parsed_version);
+	ret = fu_plugin_runner_update (plugin, tree->fu_device, fw_data, 0, &error);
+	g_assert_no_error (error);
+	g_assert_true (ret);
 
 	/* we wait until the plugin has picked up all the
 	 * subtree changes, and make sure we still receive
@@ -1188,6 +1190,19 @@ test_update_fail (ThunderboltTest *tt, gconstpointer user_data)
 	ret = mock_tree_settle (tree, plugin);
 	g_assert_true (ret);
 
+	ret = fu_plugin_runner_update_attach (plugin, tree->fu_device, &error);
+	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL);
+	g_assert_false (ret);
+
+	/* make sure all pending events have happened */
+	ret = mock_tree_settle (tree, plugin);
+	g_assert_true (ret);
+
+	/* version should *not* have changed (but we get parsed version) */
+	version_after = fu_device_get_version (tree->fu_device);
+	g_debug ("version after update: %s", version_after);
+	g_assert_cmpstr (version_after, ==, tree->device->nvm_parsed_version);
+
 	ret = mock_tree_all (tree, mock_tree_node_have_fu_device, NULL);
 	g_assert_true (ret);
 }
@@ -1213,52 +1228,16 @@ test_update_fail_nowshow (ThunderboltTest *tt, gconstpointer user_data)
 	up_ctx = mock_tree_prepare_for_update (tree, plugin, "42.23", fw_data, 1000);
 	up_ctx->result = UPDATE_FAIL_DEVICE_NOSHOW;
 
-	/* lets make the plugin only wait a second for the device */
-	fu_plugin_thunderbolt_set_timeout (plugin, 1000);
-
-	ret = fu_plugin_runner_update (plugin, tree->fu_device, NULL, fw_data, 0, &error);
-	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND);
-	g_assert_false (ret);
-}
-
-static void
-test_update_fail_tooslow (ThunderboltTest *tt, gconstpointer user_data)
-{
-	FuPlugin *plugin = tt->plugin;
-	MockTree *tree = tt->tree;
-	GBytes *fw_data = tt->fw_data;
-	gboolean ret;
-	g_autoptr(GError) error = NULL;
-	g_autoptr(UpdateContext) up_ctx = NULL;
-
-	/* test sanity check */
-	g_assert_nonnull (tree);
-	g_assert_nonnull (fw_data);
-
-	/* simulate an update, as in test_update_working, that is also working,
-	 * but that takes longer then our timeout, i.e. set_timeout < last
-	 * param in prepare_for_update. We will report an error, but we want
-	 * to make sure that the device tree afterwards is still correct
-	 */
-	up_ctx = mock_tree_prepare_for_update (tree, plugin, "42.23", fw_data, 2000);
-	up_ctx->result = UPDATE_SUCCESS;
-
-	/* lets make the plugin only wait half a second (1/4 of update time)  */
-	fu_plugin_thunderbolt_set_timeout (plugin, 500);
-
-	ret = fu_plugin_runner_update (plugin, tree->fu_device, NULL, fw_data, 0, &error);
-	g_assert_error (error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND);
-	g_assert_false (ret);
-
-	/* we wait until we see all devices again */
-	ret = mock_tree_settle (tree, plugin);
+	ret = fu_plugin_runner_update (plugin, tree->fu_device, fw_data, 0, &error);
+	g_assert_no_error (error);
 	g_assert_true (ret);
 
+	mock_tree_sync (tree, plugin, 500);
+
 	ret = mock_tree_all (tree, mock_tree_node_have_fu_device, NULL);
-	g_assert_true (ret);
+	g_assert_false (ret);
 }
 
-
 int
 main (int argc, char **argv)
 {
@@ -1309,12 +1288,5 @@ main (int argc, char **argv)
 		    test_update_fail_nowshow,
 		    test_tear_down);
 
-	g_test_add ("/thunderbolt/update{failing-tooslow}",
-		    ThunderboltTest,
-		    TEST_INIT_FULL,
-		    test_set_up,
-		    test_update_fail_tooslow,
-		    test_tear_down);
-
 	return g_test_run ();
 }
