@@ -642,9 +642,9 @@ compare_pd_existence (guint16 id,
 }
 
 FuPluginValidation
-fu_plugin_thunderbolt_validate_image (GBytes  *controller_fw,
-				      GBytes  *blob_fw,
-				      GError **error)
+fu_thunderbolt_image_validate (GBytes  *controller_fw,
+			       GBytes  *blob_fw,
+			       GError **error)
 {
 	gboolean is_host;
 	guint16 device_id;
@@ -779,16 +779,18 @@ fu_plugin_thunderbolt_validate_image (GBytes  *controller_fw,
 }
 
 gboolean
-fu_plugin_thunderbolt_controller_is_native (GBytes    *controller_fw,
-					    gboolean  *is_native,
-					    GError   **error)
+fu_thunderbolt_image_controller_is_native (GBytes    *controller_fw,
+					   gboolean  *is_native,
+					   GError   **error)
 {
 	guint32 controller_sections[SECTION_COUNT] = { [DIGITAL_SECTION] = 0 };
 	gsize fw_size;
 	const guint8 *fw_data = g_bytes_get_data (controller_fw, &fw_size);
 	const FuThunderboltFwObject controller = { fw_data, fw_size, controller_sections };
-
-	const FuThunderboltFwLocation location = { .offset = 0x7B, .len = 1, .description = "Native", .mask = 0x20 };
-
+	const FuThunderboltFwLocation location = {
+		.offset = FU_TBT_OFFSET_NATIVE,
+		.len = 1,
+		.description = "Native",
+		.mask = 0x20 };
 	return read_bool (&location, &controller, is_native, error);
 }
