@@ -7,7 +7,6 @@
 #include "config.h"
 
 #include <fwupd.h>
-#include <appstream-glib.h>
 #include <glib/gstdio.h>
 #include <string.h>
 
@@ -549,7 +548,6 @@ fu_rom_load_data (FuRom *self,
 	guint32 sz = buffer_sz;
 	guint32 jump = 0;
 	guint32 hdr_sz = 0;
-	g_autofree gchar *id = NULL;
 	g_autoptr(GChecksum) checksum_sha1 = g_checksum_new (G_CHECKSUM_SHA1);
 	g_autoptr(GChecksum) checksum_sha256 = g_checksum_new (G_CHECKSUM_SHA256);
 
@@ -687,10 +685,8 @@ fu_rom_load_data (FuRom *self,
 	g_ptr_array_add (self->checksums, g_strdup (g_checksum_get_string (checksum_sha256)));
 
 	/* update guid */
-	id = g_strdup_printf ("PCI\\VEN_%04X&DEV_%04X",
-			      self->vendor_id, self->device_id);
-	self->guid = as_utils_guid_from_string (id);
-	g_debug ("using %s for %s", self->guid, id);
+	self->guid = g_strdup_printf ("PCI\\VEN_%04X&DEV_%04X",
+				      self->vendor_id, self->device_id);
 
 	/* not known */
 	if (self->version == NULL) {
@@ -715,14 +711,10 @@ fu_rom_load_file (FuRom *self, GFile *file, FuRomLoadFlags flags,
 	g_autofree gchar *fn = NULL;
 	g_autofree guint8 *buffer = NULL;
 	g_autoptr(GFileOutputStream) output_stream = NULL;
-	g_autoptr(AsProfile) profile = as_profile_new ();
-	g_autoptr(AsProfileTask) ptask = NULL;
 
 	g_return_val_if_fail (FU_IS_ROM (self), FALSE);
 
 	/* open file */
-	ptask = as_profile_start_literal (profile, "FuRom:reading-data");
-	g_assert (ptask != NULL);
 	self->stream = G_INPUT_STREAM (g_file_read (file, cancellable, &error_local));
 	if (self->stream == NULL) {
 		g_set_error_literal (error,
