@@ -74,7 +74,12 @@ fu_plugin_get_results (FuPlugin *plugin, FuDevice *device, GError **error)
 	}
 
 	/* something went wrong */
-	fu_device_set_update_state (device, FWUPD_UPDATE_STATE_FAILED);
+	if (status == FU_UEFI_DEVICE_STATUS_ERROR_PWR_EVT_AC ||
+	    status == FU_UEFI_DEVICE_STATUS_ERROR_PWR_EVT_BATT) {
+		fu_device_set_update_state (device, FWUPD_UPDATE_STATE_FAILED_TRANSIENT);
+	} else {
+		fu_device_set_update_state (device, FWUPD_UPDATE_STATE_FAILED);
+	}
 	version_str = g_strdup_printf ("%u", fu_uefi_device_get_version_error (device_uefi));
 	tmp = fu_uefi_device_status_to_string (status);
 	if (tmp == NULL) {
@@ -282,6 +287,13 @@ fu_plugin_uefi_update_splash (FuPlugin *plugin, FuDevice *device, GError **error
 		{ 0, 0 }
 	};
 
+	/* no UX capsule support, so deleting var if it exists */
+	if (fu_device_has_custom_flag (device, "no-ux-capsule")) {
+		g_debug ("not providing UX capsule");
+		return fu_uefi_vars_delete (FU_UEFI_VARS_GUID_FWUPDATE,
+					    "fwupd-ux-capsule", error);
+	}
+
 	/* get the boot graphics resource table data */
 	if (!fu_uefi_bgrt_get_supported (data->bgrt)) {
 		g_set_error_literal (error,
@@ -403,7 +415,7 @@ fu_plugin_update (FuPlugin *plugin,
 		g_debug ("failed to upload UEFI UX capsule text: %s",
 			 error_splash->message);
 	}
-	if (!fu_device_write_firmware (device, blob_fw, error))
+	if (!fu_device_write_firmware (device, blob_fw, flags, error))
 		return FALSE;
 
 	/* record if we had an invalid header during update */
@@ -413,7 +425,8 @@ fu_plugin_update (FuPlugin *plugin,
 	/* record boot information to system log for future debugging */
 	efibootmgr_path = fu_common_find_program_in_path ("efibootmgr", NULL);
 	if (efibootmgr_path != NULL) {
-		if (!g_spawn_command_line_sync ("efibootmgr -v",
+		g_autofree gchar *cmd = g_strdup_printf ("%s -v", efibootmgr_path);
+		if (!g_spawn_command_line_sync (cmd,
 						&boot_variables, NULL, NULL, error))
 			return FALSE;
 		g_message ("Boot Information:\n%s", boot_variables);
@@ -445,7 +458,7 @@ fu_plugin_device_registered (FuPlugin *plugin, FuDevice *device)
 	}
 }
 
-static FuVersionFormat
+static FwupdVersionFormat
 fu_plugin_uefi_get_version_format_for_type (FuPlugin *plugin, FuUefiDeviceKind device_kind)
 {
 	const gchar *content;
@@ -454,19 +467,19 @@ fu_plugin_uefi_get_version_format_for_type (FuPlugin *plugin, FuUefiDeviceKind d
 
 	/* we have no information for devices */
 	if (device_kind == FU_UEFI_DEVICE_KIND_DEVICE_FIRMWARE)
-		return FU_VERSION_FORMAT_TRIPLET;
+		return FWUPD_VERSION_FORMAT_TRIPLET;
 
 	content = fu_plugin_get_dmi_value (plugin, FU_HWIDS_KEY_MANUFACTURER);
 	if (content == NULL)
-		return FU_VERSION_FORMAT_TRIPLET;
+		return FWUPD_VERSION_FORMAT_TRIPLET;
 
 	/* any quirks match */
 	group = g_strdup_printf ("SmbiosManufacturer=%s", content);
 	quirk = fu_plugin_lookup_quirk_by_id (plugin, group,
 					      FU_QUIRKS_UEFI_VERSION_FORMAT);
 	if (quirk == NULL)
-		return FU_VERSION_FORMAT_TRIPLET;
-	return fu_common_version_format_from_string (quirk);
+		return FWUPD_VERSION_FORMAT_TRIPLET;
+	return fwupd_version_format_from_string (quirk);
 }
 
 static const gchar *
@@ -509,7 +522,7 @@ static gboolean
 fu_plugin_uefi_coldplug_device (FuPlugin *plugin, FuUefiDevice *dev, GError **error)
 {
 	FuUefiDeviceKind device_kind;
-	FuVersionFormat version_format;
+	FwupdVersionFormat version_format;
 
 	/* set default version format */
 	device_kind = fu_uefi_device_get_kind (dev);
@@ -520,10 +533,13 @@ fu_plugin_uefi_coldplug_device (FuPlugin *plugin, FuUefiDevice *dev, GError **er
 	if (!fu_device_probe (FU_DEVICE (dev), error))
 		return FALSE;
 
-	/* set this flag for all Lenovo hardware */
-	if (fu_plugin_check_hwid (plugin, "6de5d951-d755-576b-bd09-c5cf66b27234")) {
-		fu_device_set_custom_flags (FU_DEVICE (dev), "use-legacy-bootmgr-desc");
-		fu_plugin_add_report_metadata (plugin, "BootMgrDesc", "legacy");
+	/* if not already set by quirks */
+	if (fu_device_get_custom_flags (FU_DEVICE (dev)) == NULL) {
+		/* for all Lenovo hardware */
+		if (fu_plugin_check_hwid (plugin, "6de5d951-d755-576b-bd09-c5cf66b27234")) {
+			fu_device_set_custom_flags (FU_DEVICE (dev), "use-legacy-bootmgr-desc");
+			fu_plugin_add_report_metadata (plugin, "BootMgrDesc", "legacy");
+		}
 	}
 
 	/* set fallback name if nothing else is set */
@@ -575,10 +591,41 @@ fu_plugin_uefi_delete_old_capsules (FuPlugin *plugin, GError **error)
 gboolean
 fu_plugin_startup (FuPlugin *plugin, GError **error)
 {
-	/* are the EFI dirs set up so we can update each device */
-	if (!fu_uefi_vars_supported (error))
+	const guint8 *data;
+	gsize sz;
+	g_autoptr(GBytes) bios_information = fu_plugin_get_smbios_data (plugin, 0);
+	if (bios_information == NULL) {
+		const gchar *tmp = g_getenv ("FWUPD_DELL_FAKE_SMBIOS");
+		if (tmp != NULL)
+			return TRUE;
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOT_SUPPORTED,
+				     "SMBIOS not supported");
 		return FALSE;
-
+	}
+	data = g_bytes_get_data (bios_information, &sz);
+	if (sz < 0x13) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_INVALID_FILE,
+			     "offset bigger than size %" G_GSIZE_FORMAT, sz);
+		return FALSE;
+	}
+	if (data[1] < 0x13) {
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOT_SUPPORTED,
+				     "SMBIOS 2.3 not supported");
+		return FALSE;
+	}
+	if (!(data[0x13] & (1 << 3))) {
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOT_SUPPORTED,
+				     "System does not support UEFI mode");
+		return FALSE;
+	}
 	/* test for invalid ESP in coldplug, and set the update-error rather
 	 * than showing no output if the plugin had self-disabled here */
 	return TRUE;
@@ -619,12 +666,11 @@ fu_plugin_uefi_ensure_esp_path (FuPlugin *plugin, GError **error)
 	/* try to guess from heuristics */
 	data->esp_path = fu_uefi_guess_esp_path ();
 	if (data->esp_path == NULL) {
-		g_set_error (error,
-			     G_IO_ERROR,
-			     G_IO_ERROR_INVALID_FILENAME,
-			     "Unable to determine EFI system partition location, "
-			     "override using OverrideESPMountPoint in %s.conf",
-			     fu_plugin_get_name (plugin));
+		g_set_error_literal (error,
+				     G_IO_ERROR,
+				     G_IO_ERROR_INVALID_FILENAME,
+				     "Unable to determine EFI system partition location, "
+				     "See https://github.com/hughsie/fwupd/wiki/Determining-EFI-system-partition-location");
 		return FALSE;
 	}
 
@@ -723,7 +769,38 @@ fu_plugin_unlock (FuPlugin *plugin, FuDevice *device, GError **error)
 	fu_device_set_flags (device_alt, device_flags_alt & ~FWUPD_DEVICE_FLAG_UPDATABLE);
 
 	/* make sure that this unlocked device can be updated */
-	fu_device_set_version (device, "0.0.0.0");
+	fu_device_set_version (device, "0.0.0.0", FWUPD_VERSION_FORMAT_QUAD);
+	return TRUE;
+}
+
+static gboolean
+fu_plugin_uefi_create_dummy (FuPlugin *plugin, GError **error)
+{
+	const gchar *key;
+	g_autoptr(FuDevice) dev = fu_device_new ();
+
+	key = fu_plugin_get_dmi_value (plugin, FU_HWIDS_KEY_MANUFACTURER);
+	if (key != NULL)
+		fu_device_set_vendor (dev, key);
+	key = fu_plugin_uefi_get_name_for_type (plugin, FU_UEFI_DEVICE_KIND_SYSTEM_FIRMWARE);
+	fu_device_set_name (dev, key);
+	key = fu_plugin_get_dmi_value (plugin, FU_HWIDS_KEY_BIOS_VERSION);
+	if (key != NULL)
+		fu_device_set_version (dev, key, FWUPD_VERSION_FORMAT_PLAIN);
+	key = "Firmware can not be updated in legacy mode, switch to UEFI mode.";
+	fu_device_set_update_error (dev, key);
+
+	fu_device_add_flag (dev, FWUPD_DEVICE_FLAG_INTERNAL);
+	fu_device_add_flag (dev, FWUPD_DEVICE_FLAG_NEEDS_REBOOT);
+	fu_device_add_flag (dev, FWUPD_DEVICE_FLAG_REQUIRE_AC);
+
+	fu_device_add_icon (dev, "computer");
+	fu_device_set_plugin (dev, fu_plugin_get_name (plugin));
+	fu_device_set_id (dev, "UEFI-dummy");
+	fu_device_add_instance_id (dev, "main-system-firmware");
+	if (!fu_device_setup (dev, error))
+		return FALSE;
+	fu_plugin_device_add (plugin, dev);
 
 	return TRUE;
 }
@@ -742,6 +819,12 @@ fu_plugin_coldplug (FuPlugin *plugin, GError **error)
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GPtrArray) entries = NULL;
 
+	/* are the EFI dirs set up so we can update each device */
+	if (!fu_uefi_vars_supported (&error_local)) {
+		g_warning ("%s", error_local->message);
+		return fu_plugin_uefi_create_dummy (plugin, error);
+	}
+
 	/* get the directory of ESRT entries */
 	sysfsfwdir = fu_common_get_path (FU_PATH_KIND_SYSFSDIR_FW);
 	esrt_path = g_build_filename (sysfsfwdir, "efi", "esrt", NULL);
@@ -755,8 +838,11 @@ fu_plugin_coldplug (FuPlugin *plugin, GError **error)
 
 	/* if secure boot is enabled ensure we have a signed fwupd.efi */
 	bootloader = fu_uefi_get_built_app_path (&error_bootloader);
-	if (bootloader == NULL)
+	if (bootloader == NULL) {
+		if (fu_uefi_secure_boot_enabled ())
+			g_prefix_error (&error_bootloader, "missing signed bootloader for secure boot: ");
 		g_warning ("%s", error_bootloader->message);
+	}
 
 	/* ensure the ESP is detected */
 	if (!fu_plugin_uefi_ensure_esp_path (plugin, &error_esp))
