@@ -11,6 +11,8 @@
 #include <gio/gio.h>
 #include <stdio.h>
 
+#include "fwupd-error.h"
+
 #include "fu-ucs2.h"
 #include "fu-uefi-bootmgr.h"
 #include "fu-uefi-common.h"
@@ -101,11 +103,10 @@ fu_uefi_setup_bootnext_with_dp (const guint8 *dp_buf, guint8 *opt, gssize opt_si
 	g_autofree guint8 *var_data = NULL;
 
 	while ((rc = efi_get_next_variable_name (&guid, &name)) > 0) {
+		const gchar *desc;
 		gint div, mod;
 		gint scanned = 0;
-		gssize sz;
 		guint16 entry = 0;
-		efidp found_dp;
 		g_autofree guint8 *var_data_tmp = NULL;
 
 		if (efi_guid_cmp (guid, &efi_guid_global) != 0)
@@ -140,24 +141,10 @@ fu_uefi_setup_bootnext_with_dp (const guint8 *dp_buf, guint8 *opt, gssize opt_si
 			continue;
 		}
 
-		sz = efi_loadopt_pathlen(loadopt, var_data_size);
-		if (sz != efidp_size((efidp)dp_buf)) {
-			g_debug ("pathlen device path doesn't match");
-			continue;
-		}
-
-		found_dp = efi_loadopt_path (loadopt, var_data_size);
-		if (memcmp (found_dp, dp_buf, sz)) {
-			g_debug ("found_dp/dp_buf device path doesn't match");
-		}
-
-		if ((gssize)var_data_size != opt_size) {
-			g_debug ("variable data doesn't match");
-			continue;
-		}
-
-		if (memcmp (loadopt, opt, opt_size)) {
-			g_debug ("load option doesn't match");
+		desc = (const gchar *) efi_loadopt_desc (loadopt, var_data_size);
+		if (g_strcmp0 (desc, "Linux Firmware Updater") != 0 &&
+		    g_strcmp0 (desc, "Linux-Firmware-Updater") != 0) {
+			g_debug ("description does not match");
 			continue;
 		}
 
@@ -343,8 +330,8 @@ fu_uefi_bootmgr_bootnext (const gchar *esp_path,
 		if (fu_uefi_secure_boot_enabled () &&
 		    (flags & FU_UEFI_BOOTMGR_FLAG_USE_SHIM_FOR_SB) > 0) {
 			g_set_error_literal (error,
-					     G_IO_ERROR,
-					     G_IO_ERROR_FAILED,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_BROKEN_SYSTEM,
 					     "Secure boot is enabled, but shim isn't installed to the EFI system partition");
 			return FALSE;
 		}
