@@ -971,7 +971,7 @@ fu_common_get_path (FuPathKind path_kind)
 		if (tmp != NULL)
 			return g_strdup (tmp);
 		return g_strdup ("/sys/firmware");
-	/* /sys/firmware */
+	/* /sys/class/tpm */
 	case FU_PATH_KIND_SYSFSDIR_TPM:
 		tmp = g_getenv ("FWUPD_SYSFSTPMDIR");
 		if (tmp != NULL)
@@ -1035,6 +1035,12 @@ fu_common_get_path (FuPathKind path_kind)
 	case FU_PATH_KIND_CACHEDIR_PKG:
 		basedir = fu_common_get_path (FU_PATH_KIND_LOCALSTATEDIR);
 		return g_build_filename (basedir, "cache", PACKAGE_NAME, NULL);
+	case FU_PATH_KIND_POLKIT_ACTIONS:
+#ifdef POLKIT_ACTIONDIR
+		return g_strdup (POLKIT_ACTIONDIR);
+#else
+	return NULL;
+#endif
 	/* this shouldn't happen */
 	default:
 		g_warning ("cannot build path for unknown kind %u", path_kind);
@@ -1200,7 +1206,7 @@ fu_common_dump_raw (const gchar *log_domain,
 }
 
 /**
- * fu_common_dump_raw:
+ * fu_common_dump_bytes:
  * @log_domain: log domain, typically %G_LOG_DOMAIN or %NULL
  * @title: prefix title, or %NULL
  * @bytes: a #GBytes
