@@ -38,13 +38,12 @@ typedef struct {
 	FuDevice			*parent;	/* noref */
 	FuQuirks			*quirks;
 	GHashTable			*metadata;
-	FuMutex				*metadata_mutex;
+	GRWLock				 metadata_mutex;
 	GPtrArray			*parent_guids;
-	FuMutex				*parent_guids_mutex;
+	GRWLock				 parent_guids_mutex;
 	GPtrArray			*children;
 	guint				 remove_delay;	/* ms */
 	FwupdStatus			 status;
-	FuVersionFormat			 version_format;
 	guint				 progress;
 	guint				 order;
 	guint				 priority;
@@ -63,7 +62,6 @@ enum {
 	PROP_PHYSICAL_ID,
 	PROP_LOGICAL_ID,
 	PROP_QUIRKS,
-	PROP_VERSION_FORMAT,
 	PROP_LAST
 };
 
@@ -83,9 +81,6 @@ fu_device_get_property (GObject *object, guint prop_id,
 	case PROP_PROGRESS:
 		g_value_set_uint (value, priv->progress);
 		break;
-	case PROP_VERSION_FORMAT:
-		g_value_set_uint (value, priv->version_format);
-		break;
 	case PROP_PHYSICAL_ID:
 		g_value_set_string (value, fu_device_get_physical_id (self));
 		break;
@@ -113,9 +108,6 @@ fu_device_set_property (GObject *object, guint prop_id,
 	case PROP_PROGRESS:
 		fu_device_set_progress (self, g_value_get_uint (value));
 		break;
-	case PROP_VERSION_FORMAT:
-		fu_device_set_version_format (self, g_value_get_uint (value));
-		break;
 	case PROP_PHYSICAL_ID:
 		fu_device_set_physical_id (self, g_value_get_string (value));
 		break;
@@ -220,6 +212,7 @@ guint
 fu_device_get_order (FuDevice *self)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
+	g_return_val_if_fail (FU_IS_DEVICE (self), 0);
 	return priv->order;
 }
 
@@ -237,6 +230,7 @@ void
 fu_device_set_order (FuDevice *self, guint order)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
+	g_return_if_fail (FU_IS_DEVICE (self));
 	priv->order = order;
 }
 
@@ -254,6 +248,7 @@ guint
 fu_device_get_priority (FuDevice *self)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
+	g_return_val_if_fail (FU_IS_DEVICE (self), 0);
 	return priv->priority;
 }
 
@@ -270,6 +265,7 @@ void
 fu_device_set_priority (FuDevice *self, guint priority)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
+	g_return_if_fail (FU_IS_DEVICE (self));
 	priv->priority = priority;
 }
 
@@ -401,12 +397,14 @@ fu_device_set_parent (FuDevice *self, FuDevice *parent)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
 
+	g_return_if_fail (FU_IS_DEVICE (self));
+
 	g_object_add_weak_pointer (G_OBJECT (parent), (gpointer *) &priv->parent);
 	priv->parent = parent;
 
 	/* this is what goes over D-Bus */
 	fwupd_device_set_parent_id (FWUPD_DEVICE (self),
-				    self != NULL ? fu_device_get_id (parent) : NULL);
+				    parent != NULL ? fu_device_get_id (parent) : NULL);
 }
 
 /**
@@ -454,10 +452,20 @@ fu_device_add_child (FuDevice *self, FuDevice *child)
 	g_ptr_array_add (priv->children, g_object_ref (child));
 
 	/* copy from main device if unset */
+	if (fu_device_get_physical_id (child) == NULL &&
+	    fu_device_get_physical_id (self) != NULL)
+		fu_device_set_physical_id (child, fu_device_get_physical_id (self));
 	if (fu_device_get_vendor (child) == NULL)
 		fu_device_set_vendor (child, fu_device_get_vendor (self));
 	if (fu_device_get_vendor_id (child) == NULL)
 		fu_device_set_vendor_id (child, fu_device_get_vendor_id (self));
+	if (fu_device_get_icons(child)->len == 0) {
+		GPtrArray *icons = fu_device_get_icons (self);
+		for (guint i = 0; i < icons->len; i++) {
+			const gchar *icon_name = g_ptr_array_index (icons, i);
+			fu_device_add_icon (child, icon_name);
+		}
+	}
 
 	/* ensure the parent is also set on the child */
 	fu_device_set_parent (child, self);
@@ -487,7 +495,7 @@ GPtrArray *
 fu_device_get_parent_guids (FuDevice *self)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->parent_guids_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->parent_guids_mutex);
 	g_return_val_if_fail (FU_IS_DEVICE (self), NULL);
 	g_return_val_if_fail (locker != NULL, NULL);
 	return priv->parent_guids;
@@ -508,7 +516,7 @@ gboolean
 fu_device_has_parent_guid (FuDevice *self, const gchar *guid)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->parent_guids_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->parent_guids_mutex);
 	g_return_val_if_fail (FU_IS_DEVICE (self), FALSE);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	for (guint i = 0; i < priv->parent_guids->len; i++) {
@@ -539,7 +547,8 @@ void
 fu_device_add_parent_guid (FuDevice *self, const gchar *guid)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
+
 	g_return_if_fail (FU_IS_DEVICE (self));
 	g_return_if_fail (guid != NULL);
 
@@ -556,7 +565,7 @@ fu_device_add_parent_guid (FuDevice *self, const gchar *guid)
 	/* already valid */
 	if (fu_device_has_parent_guid (self, guid))
 		return;
-	locker = fu_mutex_write_locker_new (priv->parent_guids_mutex);
+	locker = g_rw_lock_writer_locker_new (&priv->parent_guids_mutex);
 	g_return_if_fail (locker != NULL);
 	g_ptr_array_add (priv->parent_guids, g_strdup (guid));
 }
@@ -655,7 +664,7 @@ fu_device_set_quirk_kv (FuDevice *self,
 		return TRUE;
 	}
 	if (g_strcmp0 (key, FU_QUIRKS_VERSION) == 0) {
-		fu_device_set_version (self, value);
+		fu_device_set_version (self, value, fu_device_get_version_format (self));
 		return TRUE;
 	}
 	if (g_strcmp0 (key, FU_QUIRKS_ICON) == 0) {
@@ -691,7 +700,7 @@ fu_device_set_quirk_kv (FuDevice *self,
 		return TRUE;
 	}
 	if (g_strcmp0 (key, FU_QUIRKS_VERSION_FORMAT) == 0) {
-		fu_device_set_version_format (self, fu_common_version_format_from_string (value));
+		fu_device_set_version_format (self, fwupd_version_format_from_string (value));
 		return TRUE;
 	}
 	if (g_strcmp0 (key, FU_QUIRKS_CHILDREN) == 0) {
@@ -850,6 +859,9 @@ fu_device_add_guid_safe (FuDevice *self, const gchar *guid)
 gboolean
 fu_device_has_guid (FuDevice *self, const gchar *guid)
 {
+	g_return_val_if_fail (FU_IS_DEVICE (self), FALSE);
+	g_return_val_if_fail (guid != NULL, FALSE);
+
 	/* make valid */
 	if (!fwupd_guid_is_valid (guid)) {
 		g_autofree gchar *tmp = fwupd_guid_hash_string (guid);
@@ -860,6 +872,29 @@ fu_device_has_guid (FuDevice *self, const gchar *guid)
 	return fwupd_device_has_guid (FWUPD_DEVICE (self), guid);
 }
 
+/* private */
+void
+fu_device_add_instance_id_full (FuDevice *self,
+				const gchar *instance_id,
+				FuDeviceInstanceFlags flags)
+{
+	g_autofree gchar *guid = NULL;
+	if (fwupd_guid_is_valid (instance_id)) {
+		g_warning ("use fu_device_add_guid(\"%s\") instead!", instance_id);
+		fu_device_add_guid_safe (self, instance_id);
+		return;
+	}
+
+	/* it seems odd adding the instance ID and the GUID quirks and not just
+	 * calling fu_device_add_guid_safe() -- but we want the quirks to match
+	 * so the plugin is set, but not the LVFS metadata to match firmware
+	 * until we're sure the device isn't using _NO_AUTO_INSTANCE_IDS */
+	guid = fwupd_guid_hash_string (instance_id);
+	fu_device_add_guid_quirks (self, guid);
+	if ((flags & FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS) == 0)
+		fwupd_device_add_instance_id (FWUPD_DEVICE (self), instance_id);
+}
+
 /**
  * fu_device_add_instance_id:
  * @self: A #FuDevice
@@ -873,19 +908,9 @@ fu_device_has_guid (FuDevice *self, const gchar *guid)
 void
 fu_device_add_instance_id (FuDevice *self, const gchar *instance_id)
 {
-	g_autofree gchar *guid = NULL;
-	if (fwupd_guid_is_valid (instance_id)) {
-		g_warning ("use fu_device_add_guid(\"%s\") instead!", instance_id);
-		fu_device_add_guid_safe (self, instance_id);
-		return;
-	}
-	/* it seems odd adding the instance ID and the GUID quirks and not just
-	 * calling fu_device_add_guid_safe() -- but we want the quirks to match
-	 * so the plugin is set, but not the LVFS metadata to match firmware
-	 * until we're sure the device isn't using _NO_AUTO_INSTANCE_IDS */
-	guid = fwupd_guid_hash_string (instance_id);
-	fu_device_add_guid_quirks (self, guid);
-	fwupd_device_add_instance_id (FWUPD_DEVICE (self), instance_id);
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (instance_id != NULL);
+	fu_device_add_instance_id_full (self, instance_id, FU_DEVICE_INSTANCE_FLAG_NONE);
 }
 
 /**
@@ -901,6 +926,8 @@ fu_device_add_instance_id (FuDevice *self, const gchar *instance_id)
 void
 fu_device_add_guid (FuDevice *self, const gchar *guid)
 {
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (guid != NULL);
 	if (!fwupd_guid_is_valid (guid)) {
 		fu_device_add_instance_id (self, guid);
 		return;
@@ -925,6 +952,9 @@ fu_device_add_guid (FuDevice *self, const gchar *guid)
 void
 fu_device_add_counterpart_guid (FuDevice *self, const gchar *guid)
 {
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (guid != NULL);
+
 	/* make valid */
 	if (!fwupd_guid_is_valid (guid)) {
 		g_autofree gchar *tmp = fwupd_guid_hash_string (guid);
@@ -950,8 +980,13 @@ fu_device_add_counterpart_guid (FuDevice *self, const gchar *guid)
 gchar *
 fu_device_get_guids_as_str (FuDevice *self)
 {
-	GPtrArray *guids = fu_device_get_guids (self);
-	g_autofree gchar **tmp = g_new0 (gchar *, guids->len + 1);
+	GPtrArray *guids;
+	g_autofree gchar **tmp = NULL;
+
+	g_return_val_if_fail (FU_IS_DEVICE (self), NULL);
+
+	guids = fu_device_get_guids (self);
+	tmp = g_new0 (gchar *, guids->len + 1);
 	for (guint i = 0; i < guids->len; i++)
 		tmp[i] = g_ptr_array_index (guids, i);
 	return g_strjoinv (",", tmp);
@@ -972,7 +1007,7 @@ const gchar *
 fu_device_get_metadata (FuDevice *self, const gchar *key)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->metadata_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->metadata_mutex);
 	g_return_val_if_fail (FU_IS_DEVICE (self), NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 	g_return_val_if_fail (locker != NULL, NULL);
@@ -995,10 +1030,12 @@ fu_device_get_metadata_boolean (FuDevice *self, const gchar *key)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
 	const gchar *tmp;
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->metadata_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->metadata_mutex);
+
 	g_return_val_if_fail (FU_IS_DEVICE (self), FALSE);
 	g_return_val_if_fail (key != NULL, FALSE);
 	g_return_val_if_fail (locker != NULL, FALSE);
+
 	tmp = g_hash_table_lookup (priv->metadata, key);
 	if (tmp == NULL)
 		return FALSE;
@@ -1023,7 +1060,7 @@ fu_device_get_metadata_integer (FuDevice *self, const gchar *key)
 	const gchar *tmp;
 	gchar *endptr = NULL;
 	guint64 val;
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->metadata_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->metadata_mutex);
 
 	g_return_val_if_fail (FU_IS_DEVICE (self), G_MAXUINT);
 	g_return_val_if_fail (key != NULL, G_MAXUINT);
@@ -1054,7 +1091,7 @@ void
 fu_device_set_metadata (FuDevice *self, const gchar *key, const gchar *value)
 {
 	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_write_locker_new (priv->metadata_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_writer_locker_new (&priv->metadata_mutex);
 	g_return_if_fail (FU_IS_DEVICE (self));
 	g_return_if_fail (key != NULL);
 	g_return_if_fail (value != NULL);
@@ -1076,6 +1113,9 @@ fu_device_set_metadata (FuDevice *self, const gchar *key, const gchar *value)
 void
 fu_device_set_metadata_boolean (FuDevice *self, const gchar *key, gboolean value)
 {
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (key != NULL);
+
 	fu_device_set_metadata (self, key, value ? "true" : "false");
 }
 
@@ -1094,6 +1134,10 @@ void
 fu_device_set_metadata_integer (FuDevice *self, const gchar *key, guint value)
 {
 	g_autofree gchar *tmp = g_strdup_printf ("%u", value);
+
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (key != NULL);
+
 	fu_device_set_metadata (self, key, tmp);
 }
 
@@ -1111,6 +1155,9 @@ fu_device_set_name (FuDevice *self, const gchar *value)
 {
 	g_autoptr(GString) new = g_string_new (value);
 
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (value != NULL);
+
 	/* overwriting? */
 	if (g_strcmp0 (value, fu_device_get_name (self)) == 0) {
 		const gchar *id = fu_device_get_id (self);
@@ -1151,62 +1198,57 @@ fu_device_set_name (FuDevice *self, const gchar *value)
 void
 fu_device_set_id (FuDevice *self, const gchar *id)
 {
+	FuDevicePrivate *priv = GET_PRIVATE (self);
 	g_autofree gchar *id_hash = NULL;
+
 	g_return_if_fail (FU_IS_DEVICE (self));
 	g_return_if_fail (id != NULL);
+
 	id_hash = g_compute_checksum_for_string (G_CHECKSUM_SHA1, id, -1);
 	g_debug ("using %s for %s", id_hash, id);
 	fwupd_device_set_id (FWUPD_DEVICE (self), id_hash);
-}
 
-static gboolean
-fu_device_is_valid_semver_char (gchar c)
-{
-	if (g_ascii_isdigit (c))
-		return TRUE;
-	if (c == '.')
-		return TRUE;
-	return FALSE;
+	/* ensure the parent ID is set */
+	for (guint i = 0; i < priv->children->len; i++) {
+		FuDevice *devtmp = g_ptr_array_index (priv->children, i);
+		fwupd_device_set_parent_id (FWUPD_DEVICE (devtmp), id_hash);
+	}
 }
 
 /**
  * fu_device_set_version:
  * @self: A #FuDevice
  * @version: a string, e.g. `1.2.3`
+ * @fmt: a #FwupdVersionFormat, e.g. %FWUPD_VERSION_FORMAT_TRIPLET
  *
- * Sets the device version, autodetecting the version format if required.
+ * Sets the device version, sanitizing the string if required.
  *
- * Since: 1.2.1
+ * Since: 1.2.9
  **/
 void
-fu_device_set_version (FuDevice *self, const gchar *version)
+fu_device_set_version (FuDevice *self, const gchar *version, FwupdVersionFormat fmt)
 {
-	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_autoptr(GString) version_safe = NULL;
+	g_autofree gchar *version_safe = NULL;
+	g_autoptr(GError) error = NULL;
 
 	g_return_if_fail (FU_IS_DEVICE (self));
 	g_return_if_fail (version != NULL);
 
 	/* sanitize if required */
-	if (priv->version_format != FU_VERSION_FORMAT_UNKNOWN &&
-	    priv->version_format != FU_VERSION_FORMAT_PLAIN) {
-		version_safe = g_string_new (NULL);
-		for (guint i = 0; version[i] != '\0'; i++) {
-			if (fu_device_is_valid_semver_char (version[i]))
-				g_string_append_c (version_safe, version[i]);
-		}
-		if (g_strcmp0 (version, version_safe->str) != 0) {
-			g_debug ("converted '%s' to '%s'",
-				 version, version_safe->str);
-		}
+	if (fu_device_has_flag (self, FWUPD_DEVICE_FLAG_ENSURE_SEMVER)) {
+		version_safe = fu_common_version_ensure_semver (version);
+		if (g_strcmp0 (version, version_safe) != 0)
+			g_debug ("converted '%s' to '%s'", version, version_safe);
 	} else {
-		version_safe = g_string_new (version);
+		version_safe = g_strdup (version);
 	}
 
-	/* try to autodetect the version-format */
-	if (priv->version_format == FU_VERSION_FORMAT_UNKNOWN)
-		priv->version_format = fu_common_version_guess_format (version_safe->str);
-	fwupd_device_set_version (FWUPD_DEVICE (self), version_safe->str);
+	/* print a console warning for an invalid version, if semver */
+	if (!fu_common_version_verify_format (version_safe, fmt, &error))
+		g_warning ("%s", error->message);
+
+	fu_device_set_version_format (self, fmt);
+	fwupd_device_set_version (FWUPD_DEVICE (self), version_safe);
 }
 
 /**
@@ -1226,6 +1268,9 @@ fu_device_ensure_id (FuDevice *self, GError **error)
 {
 	g_autofree gchar *device_id = NULL;
 
+	g_return_val_if_fail (FU_IS_DEVICE (self), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
 	/* already set */
 	if (fu_device_get_id (self) != NULL)
 		return TRUE;
@@ -1519,43 +1564,6 @@ fu_device_set_status (FuDevice *self, FwupdStatus status)
 	g_object_notify (G_OBJECT (self), "status");
 }
 
-/**
- * fu_device_get_version_format:
- * @self: A #FuDevice
- *
- * Returns how the device version should be formatted.
- *
- * Returns: the version format, e.g. %FU_VERSION_FORMAT_TRIPLET
- *
- * Since: 1.2.0
- **/
-FuVersionFormat
-fu_device_get_version_format (FuDevice *self)
-{
-	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_return_val_if_fail (FU_IS_DEVICE (self), 0);
-	return priv->version_format;
-}
-
-/**
- * fu_device_set_version_format:
- * @self: A #FuDevice
- * @version_format: the version_format value, e.g. %FU_VERSION_FORMAT_TRIPLET
- *
- * Sets how the version should be formatted.
- *
- * Since: 1.2.0
- **/
-void
-fu_device_set_version_format (FuDevice *self, FuVersionFormat version_format)
-{
-	FuDevicePrivate *priv = GET_PRIVATE (self);
-	g_return_if_fail (FU_IS_DEVICE (self));
-	if (priv->version_format == version_format)
-		return;
-	priv->version_format = version_format;
-}
-
 /**
  * fu_device_get_progress:
  * @self: A #FuDevice
@@ -1608,6 +1616,7 @@ void
 fu_device_set_progress_full (FuDevice *self, gsize progress_done, gsize progress_total)
 {
 	gdouble percentage = 0.f;
+	g_return_if_fail (FU_IS_DEVICE (self));
 	if (progress_total > 0)
 		percentage = (100.f * (gdouble) progress_done) / (gdouble) progress_total;
 	fu_device_set_progress (self, (guint) percentage);
@@ -1631,7 +1640,7 @@ fu_device_to_string (FuDevice *self)
 	FuDevicePrivate *priv = GET_PRIVATE (self);
 	GString *str = g_string_new ("");
 	g_autofree gchar *tmp = NULL;
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->metadata_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->metadata_mutex);
 	g_autoptr(GList) keys = NULL;
 
 	g_return_val_if_fail (FU_IS_DEVICE (self), NULL);
@@ -1640,10 +1649,6 @@ fu_device_to_string (FuDevice *self)
 	tmp = fwupd_device_to_string (FWUPD_DEVICE (self));
 	if (tmp != NULL && tmp[0] != '\0')
 		g_string_append (str, tmp);
-        if (priv->version_format != FU_VERSION_FORMAT_UNKNOWN) {
-		fwupd_pad_kv_str (str, "VersionFormat",
-                                  fu_common_version_format_to_string (priv->version_format));
-        }
 	if (priv->alternate_id != NULL)
 		fwupd_pad_kv_str (str, "AlternateId", priv->alternate_id);
 	if (priv->equivalent_id != NULL)
@@ -1722,6 +1727,7 @@ FwupdRelease *
 fu_device_get_release_default (FuDevice *self)
 {
 	g_autoptr(FwupdRelease) rel = NULL;
+	g_return_val_if_fail (FU_IS_DEVICE (self), NULL);
 	if (fwupd_device_get_release_default (FWUPD_DEVICE (self)) != NULL)
 		return fwupd_device_get_release_default (FWUPD_DEVICE (self));
 	rel = fwupd_release_new ();
@@ -1733,6 +1739,7 @@ fu_device_get_release_default (FuDevice *self)
  * fu_device_write_firmware:
  * @self: A #FuDevice
  * @fw: A #GBytes
+ * @flags: #FwupdInstallFlags, e.g. %FWUPD_INSTALL_FLAG_FORCE
  * @error: A #GError
  *
  * Writes firmware to the device by calling a plugin-specific vfunc.
@@ -1742,7 +1749,10 @@ fu_device_get_release_default (FuDevice *self)
  * Since: 1.0.8
  **/
 gboolean
-fu_device_write_firmware (FuDevice *self, GBytes *fw, GError **error)
+fu_device_write_firmware (FuDevice *self,
+			  GBytes *fw,
+			  FwupdInstallFlags flags,
+			  GError **error)
 {
 	FuDeviceClass *klass = FU_DEVICE_GET_CLASS (self);
 	g_autoptr(GBytes) fw_new = NULL;
@@ -1760,18 +1770,19 @@ fu_device_write_firmware (FuDevice *self, GBytes *fw, GError **error)
 	}
 
 	/* prepare (e.g. decompress) firmware */
-	fw_new = fu_device_prepare_firmware (self, fw, error);
+	fw_new = fu_device_prepare_firmware (self, fw, flags, error);
 	if (fw_new == NULL)
 		return FALSE;
 
 	/* call vfunc */
-	return klass->write_firmware (self, fw_new, error);
+	return klass->write_firmware (self, fw_new, flags, error);
 }
 
 /**
  * fu_device_prepare_firmware:
  * @self: A #FuDevice
  * @fw: A #GBytes
+ * @flags: #FwupdInstallFlags, e.g. %FWUPD_INSTALL_FLAG_FORCE
  * @error: A #GError
  *
  * Prepares the firmware by calling an optional device-specific vfunc for the
@@ -1787,7 +1798,10 @@ fu_device_write_firmware (FuDevice *self, GBytes *fw, GError **error)
  * Since: 1.1.2
  **/
 GBytes *
-fu_device_prepare_firmware (FuDevice *self, GBytes *fw, GError **error)
+fu_device_prepare_firmware (FuDevice *self,
+			    GBytes *fw,
+			    FwupdInstallFlags flags,
+			    GError **error)
 {
 	FuDeviceClass *klass = FU_DEVICE_GET_CLASS (self);
 	FuDevicePrivate *priv = GET_PRIVATE (self);
@@ -1800,7 +1814,7 @@ fu_device_prepare_firmware (FuDevice *self, GBytes *fw, GError **error)
 
 	/* optionally subclassed */
 	if (klass->prepare_firmware != NULL) {
-		fw_new = klass->prepare_firmware (self, fw, error);
+		fw_new = klass->prepare_firmware (self, fw, flags, error);
 		if (fw_new == NULL)
 			return NULL;
 	} else {
@@ -2148,7 +2162,7 @@ fu_device_setup (FuDevice *self, GError **error)
  * @error: A #GError, or %NULL
  *
  * Activates up a device, which normally means the device switches to a new
- * firmware verson. This should only be called when data loss cannot occur.
+ * firmware version. This should only be called when data loss cannot occur.
  *
  * Returns: %TRUE for success
  *
@@ -2223,11 +2237,11 @@ fu_device_incorporate (FuDevice *self, FuDevice *donor)
 		fu_device_set_equivalent_id (self, fu_device_get_equivalent_id (donor));
 	if (priv->quirks == NULL)
 		fu_device_set_quirks (self, fu_device_get_quirks (donor));
-	fu_mutex_read_lock (priv_donor->parent_guids_mutex);
+	g_rw_lock_reader_lock (&priv_donor->parent_guids_mutex);
 	for (guint i = 0; i < parent_guids->len; i++)
 		fu_device_add_parent_guid (self, g_ptr_array_index (parent_guids, i));
-	fu_mutex_read_unlock (priv_donor->parent_guids_mutex);
-	fu_mutex_read_lock (priv_donor->metadata_mutex);
+	g_rw_lock_reader_unlock (&priv_donor->parent_guids_mutex);
+	g_rw_lock_reader_lock (&priv_donor->metadata_mutex);
 	metadata_keys = g_hash_table_get_keys (priv_donor->metadata);
 	for (GList *l = metadata_keys; l != NULL; l = l->next) {
 		const gchar *key = l->data;
@@ -2236,7 +2250,7 @@ fu_device_incorporate (FuDevice *self, FuDevice *donor)
 			fu_device_set_metadata (self, key, value);
 		}
 	}
-	fu_mutex_read_unlock (priv_donor->metadata_mutex);
+	g_rw_lock_reader_unlock (&priv_donor->metadata_mutex);
 
 	/* now the base class, where all the interesting bits are */
 	fwupd_device_incorporate (FWUPD_DEVICE (self), FWUPD_DEVICE (donor));
@@ -2248,7 +2262,7 @@ fu_device_incorporate (FuDevice *self, FuDevice *donor)
 
 /**
  * fu_device_incorporate_from_component:
- * @self: A #FuDevice
+ * @device: A #FuDevice
  * @component: A #XbNode
  *
  * Copy all properties from the donor AppStream component.
@@ -2256,12 +2270,14 @@ fu_device_incorporate (FuDevice *self, FuDevice *donor)
  * Since: 1.2.4
  **/
 void
-fu_device_incorporate_from_component (FuDevice *device, XbNode *component)
+fu_device_incorporate_from_component (FuDevice *self, XbNode *component)
 {
 	const gchar *tmp;
+	g_return_if_fail (FU_IS_DEVICE (self));
+	g_return_if_fail (XB_IS_NODE (component));
 	tmp = xb_node_query_text (component, "custom/value[@key='LVFS::UpdateMessage']", NULL);
 	if (tmp != NULL)
-		fwupd_device_set_update_message (FWUPD_DEVICE (device), tmp);
+		fwupd_device_set_update_message (FWUPD_DEVICE (self), tmp);
 }
 
 static void
@@ -2297,14 +2313,6 @@ fu_device_class_init (FuDeviceClass *klass)
 				   G_PARAM_STATIC_NAME);
 	g_object_class_install_property (object_class, PROP_PROGRESS, pspec);
 
-	pspec = g_param_spec_uint ("version-format", NULL, NULL,
-				   FU_VERSION_FORMAT_UNKNOWN,
-				   FU_VERSION_FORMAT_LAST,
-				   FU_VERSION_FORMAT_UNKNOWN,
-				   G_PARAM_READWRITE |
-				   G_PARAM_STATIC_NAME);
-	g_object_class_install_property (object_class, PROP_VERSION_FORMAT, pspec);
-
 	pspec = g_param_spec_object ("quirks", NULL, NULL,
 				     FU_TYPE_QUIRKS,
 				     G_PARAM_READWRITE |
@@ -2319,10 +2327,10 @@ fu_device_init (FuDevice *self)
 	priv->status = FWUPD_STATUS_IDLE;
 	priv->children = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	priv->parent_guids = g_ptr_array_new_with_free_func (g_free);
-	priv->parent_guids_mutex = fu_mutex_new (G_OBJECT_TYPE_NAME(self), "parent_guids");
+	g_rw_lock_init (&priv->parent_guids_mutex);
 	priv->metadata = g_hash_table_new_full (g_str_hash, g_str_equal,
 						g_free, g_free);
-	priv->metadata_mutex = fu_mutex_new (G_OBJECT_TYPE_NAME(self), "metadata");
+	g_rw_lock_init (&priv->metadata_mutex);
 }
 
 static void
@@ -2339,8 +2347,8 @@ fu_device_finalize (GObject *object)
 		g_object_unref (priv->quirks);
 	if (priv->poll_id != 0)
 		g_source_remove (priv->poll_id);
-	g_object_unref (priv->metadata_mutex);
-	g_object_unref (priv->parent_guids_mutex);
+	g_rw_lock_clear (&priv->metadata_mutex);
+	g_rw_lock_clear (&priv->parent_guids_mutex);
 	g_hash_table_unref (priv->metadata);
 	g_ptr_array_unref (priv->children);
 	g_ptr_array_unref (priv->parent_guids);
