@@ -22,9 +22,17 @@ G_BEGIN_DECLS
 #define FU_TYPE_ENGINE (fu_engine_get_type ())
 G_DECLARE_FINAL_TYPE (FuEngine, fu_engine, FU, ENGINE, GObject)
 
+/**
+ * FuEngineLoadFlags:
+ * @FU_ENGINE_LOAD_FLAG_NONE:		No flags set
+ * @FU_ENGINE_LOAD_FLAG_READONLY_FS:	Ignore readonly filesystem errors
+ *
+ * The flags to use when loading the engine.
+ **/
 typedef enum {
 	FU_ENGINE_LOAD_FLAG_NONE		= 0,
 	FU_ENGINE_LOAD_FLAG_READONLY_FS		= 1 << 0,
+	/*< private >*/
 	FU_ENGINE_LOAD_FLAG_LAST
 } FuEngineLoadFlags;
 
@@ -131,6 +139,10 @@ gchar		*fu_engine_self_sign			(FuEngine	*self,
 							 const gchar	*value,
 							 FuKeyringSignFlags flags,
 							 GError		**error);
+gboolean	 fu_engine_modify_config		(FuEngine	*self,
+							 const gchar	*key,
+							 const gchar	*value,
+							 GError		**error);
 
 /* for the self tests */
 void		 fu_engine_add_device			(FuEngine	*self,
