@@ -10,6 +10,7 @@
 
 #include <fwupd.h>
 #include <glib-object.h>
+#include <glib/gstdio.h>
 #include <gio/gio.h>
 #include <sqlite3.h>
 #include <stdlib.h>
@@ -27,7 +28,7 @@ struct _FuHistory
 {
 	GObject			 parent_instance;
 	sqlite3			*db;
-	FuMutex			*db_mutex;
+	GRWLock			 db_mutex;
 };
 
 G_DEFINE_TYPE (FuHistory, fu_history, G_TYPE_OBJECT)
@@ -114,7 +115,7 @@ fu_history_device_from_stmt (sqlite3_stmt *stmt)
 	/* version_old */
 	tmp = (const gchar *) sqlite3_column_text (stmt, 13);
 	if (tmp != NULL)
-		fu_device_set_version (device, tmp);
+		fu_device_set_version (device, tmp, FWUPD_VERSION_FORMAT_UNKNOWN);
 
 	/* checksum_device */
 	tmp = (const gchar *) sqlite3_column_text (stmt, 14);
@@ -344,6 +345,23 @@ fu_history_create_or_migrate (FuHistory *self, guint schema_ver, GError **error)
 	return fu_history_stmt_exec (self, stmt, NULL, error);
 }
 
+static gboolean
+fu_history_open (FuHistory *self, const gchar *filename, GError **error)
+{
+	gint rc;
+	g_debug ("trying to open database '%s'", filename);
+	rc = sqlite3_open (filename, &self->db);
+	if (rc != SQLITE_OK) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_READ,
+			     "Can't open %s: %s",
+			     filename, sqlite3_errmsg (self->db));
+		return FALSE;
+	}
+	return TRUE;
+}
+
 static gboolean
 fu_history_load (FuHistory *self, GError **error)
 {
@@ -352,7 +370,7 @@ fu_history_load (FuHistory *self, GError **error)
 	g_autofree gchar *dirname = NULL;
 	g_autofree gchar *filename = NULL;
 	g_autoptr(GFile) file = NULL;
-	g_autoptr(FuMutexLocker) locker = fu_mutex_write_locker_new (self->db_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 
 	/* already done */
 	if (self->db != NULL)
@@ -372,17 +390,8 @@ fu_history_load (FuHistory *self, GError **error)
 
 	/* open */
 	filename = g_build_filename (dirname, "pending.db", NULL);
-	g_debug ("trying to open database '%s'", filename);
-	rc = sqlite3_open (filename, &self->db);
-	if (rc != SQLITE_OK) {
-		g_set_error (error,
-			     FWUPD_ERROR,
-			     FWUPD_ERROR_READ,
-			     "Can't open %s: %s",
-			     filename, sqlite3_errmsg (self->db));
-		sqlite3_close (self->db);
+	if (!fu_history_open (self, filename, error))
 		return FALSE;
-	}
 
 	/* check database */
 	schema_ver = fu_history_get_schema_version (self);
@@ -398,8 +407,24 @@ fu_history_load (FuHistory *self, GError **error)
 	/* create initial up-to-date database, or migrate */
 	g_debug ("got schema version of %u", schema_ver);
 	if (schema_ver != FU_HISTORY_CURRENT_SCHEMA_VERSION) {
-		if (!fu_history_create_or_migrate (self, schema_ver, error))
-			return FALSE;
+		g_autoptr(GError) error_migrate = NULL;
+		if (!fu_history_create_or_migrate (self, schema_ver, &error_migrate)) {
+			/* this is fatal to the daemon, so delete the database
+			 * and try again with something empty */
+			g_warning ("failed to migrate %s database: %s",
+				   filename, error_migrate->message);
+			sqlite3_close (self->db);
+			if (g_unlink (filename) != 0) {
+				g_set_error (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_INTERNAL,
+					     "Can't delete %s", filename);
+				return FALSE;
+			}
+			if (!fu_history_open (self, filename, error))
+				return FALSE;
+			return fu_history_create_database (self, error);
+		}
 	}
 
 	/* success */
@@ -438,7 +463,7 @@ fu_history_modify_device (FuHistory *self, FuDevice *device,
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 	g_return_val_if_fail (FU_IS_DEVICE (device), FALSE);
@@ -448,7 +473,7 @@ fu_history_modify_device (FuHistory *self, FuDevice *device,
 		return FALSE;
 
 	/* overwrite entry if it exists */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	if ((flags & FU_HISTORY_FLAGS_MATCH_OLD_VERSION) &&
 	    (flags & FU_HISTORY_FLAGS_MATCH_NEW_VERSION)) {
@@ -517,7 +542,7 @@ fu_history_add_device (FuHistory *self, FuDevice *device, FwupdRelease *release,
 	gint rc;
 	g_autofree gchar *metadata = NULL;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 	g_return_val_if_fail (FU_IS_DEVICE (device), FALSE);
@@ -545,7 +570,7 @@ fu_history_add_device (FuHistory *self, FuDevice *device, FwupdRelease *release,
 	metadata = _convert_hash_to_string (fwupd_release_get_metadata (release));
 
 	/* add */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	rc = sqlite3_prepare_v2 (self->db,
 				 "INSERT INTO history (device_id,"
@@ -598,7 +623,7 @@ fu_history_remove_all_with_state (FuHistory *self,
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 
@@ -607,7 +632,7 @@ fu_history_remove_all_with_state (FuHistory *self,
 		return FALSE;
 
 	/* remove entries */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	g_debug ("removing all devices with update_state %s",
 		 fwupd_update_state_to_string (update_state));
@@ -629,7 +654,7 @@ fu_history_remove_all (FuHistory *self, GError **error)
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 
@@ -638,7 +663,7 @@ fu_history_remove_all (FuHistory *self, GError **error)
 		return FALSE;
 
 	/* remove entries */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	g_debug ("removing all devices");
 	rc = sqlite3_prepare_v2 (self->db, "DELETE FROM history;", -1, &stmt, NULL);
@@ -657,7 +682,7 @@ fu_history_remove_device (FuHistory *self,  FuDevice *device,
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 	g_return_val_if_fail (FU_IS_DEVICE (device), FALSE);
@@ -667,7 +692,7 @@ fu_history_remove_device (FuHistory *self,  FuDevice *device,
 	if (!fu_history_load (self, error))
 		return FALSE;
 
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	g_debug ("remove device %s [%s]",
 		 fu_device_get_name (device),
@@ -695,7 +720,7 @@ fu_history_get_device_by_id (FuHistory *self, const gchar *device_id, GError **e
 	gint rc;
 	g_autoptr(GPtrArray) array_tmp = NULL;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), NULL);
 	g_return_val_if_fail (device_id != NULL, NULL);
@@ -705,7 +730,7 @@ fu_history_get_device_by_id (FuHistory *self, const gchar *device_id, GError **e
 		return NULL;
 
 	/* get all the devices */
-	locker = fu_mutex_read_locker_new (self->db_mutex);
+	locker = g_rw_lock_reader_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, NULL);
 	g_debug ("get device");
 	rc = sqlite3_prepare_v2 (self->db,
@@ -725,7 +750,8 @@ fu_history_get_device_by_id (FuHistory *self, const gchar *device_id, GError **e
 					"version_old, "
 					"checksum_device, "
 					"protocol FROM history WHERE "
-				 "device_id = ?1 LIMIT 1", -1, &stmt, NULL);
+				 "device_id = ?1 ORDER BY device_created DESC "
+				 "LIMIT 1", -1, &stmt, NULL);
 	if (rc != SQLITE_OK) {
 		g_set_error (error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL,
 			     "Failed to prepare SQL to get history: %s",
@@ -753,7 +779,7 @@ fu_history_get_devices (FuHistory *self, GError **error)
 	g_autoptr(sqlite3_stmt) stmt = NULL;
 	gint rc;
 	g_autoptr(GPtrArray) array_tmp = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), NULL);
 
@@ -764,7 +790,7 @@ fu_history_get_devices (FuHistory *self, GError **error)
 	}
 
 	/* get all the devices */
-	locker = fu_mutex_read_locker_new (self->db_mutex);
+	locker = g_rw_lock_reader_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, NULL);
 	rc = sqlite3_prepare_v2 (self->db,
 				 "SELECT device_id, "
@@ -802,7 +828,7 @@ GPtrArray *
 fu_history_get_approved_firmware (FuHistory *self, GError **error)
 {
 	gint rc;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 	g_autoptr(GPtrArray) array = NULL;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
 
@@ -815,7 +841,7 @@ fu_history_get_approved_firmware (FuHistory *self, GError **error)
 	}
 
 	/* get all the approved firmware */
-	locker = fu_mutex_read_locker_new (self->db_mutex);
+	locker = g_rw_lock_reader_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, NULL);
 	rc = sqlite3_prepare_v2 (self->db,
 				 "SELECT checksum FROM approved_firmware;",
@@ -845,7 +871,7 @@ fu_history_clear_approved_firmware (FuHistory *self, GError **error)
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 
@@ -854,7 +880,7 @@ fu_history_clear_approved_firmware (FuHistory *self, GError **error)
 		return FALSE;
 
 	/* remove entries */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	rc = sqlite3_prepare_v2 (self->db,
 				 "DELETE FROM approved_firmware;",
@@ -875,7 +901,7 @@ fu_history_add_approved_firmware (FuHistory *self,
 {
 	gint rc;
 	g_autoptr(sqlite3_stmt) stmt = NULL;
-	g_autoptr(FuMutexLocker) locker = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = NULL;
 
 	g_return_val_if_fail (FU_IS_HISTORY (self), FALSE);
 	g_return_val_if_fail (checksum != NULL, FALSE);
@@ -885,7 +911,7 @@ fu_history_add_approved_firmware (FuHistory *self,
 		return FALSE;
 
 	/* add */
-	locker = fu_mutex_write_locker_new (self->db_mutex);
+	locker = g_rw_lock_writer_locker_new (&self->db_mutex);
 	g_return_val_if_fail (locker != NULL, FALSE);
 	rc = sqlite3_prepare_v2 (self->db,
 				 "INSERT INTO approved_firmware (checksum) "
@@ -910,7 +936,7 @@ fu_history_class_init (FuHistoryClass *klass)
 static void
 fu_history_init (FuHistory *self)
 {
-	self->db_mutex = fu_mutex_new (G_OBJECT_TYPE_NAME(self), "db");
+	g_rw_lock_init (&self->db_mutex);
 }
 
 static void
@@ -920,7 +946,7 @@ fu_history_finalize (GObject *object)
 
 	if (self->db != NULL)
 		sqlite3_close (self->db);
-	g_object_unref (self->db_mutex);
+	g_rw_lock_clear (&self->db_mutex);
 
 	G_OBJECT_CLASS (fu_history_parent_class)->finalize (object);
 }
