@@ -109,6 +109,7 @@ fu_install_task_check_requirements (FuInstallTask *self,
 				    FwupdInstallFlags flags,
 				    GError **error)
 {
+	const gchar *tmp;
 	const gchar *version;
 	const gchar *version_release;
 	const gchar *version_lowest;
@@ -217,6 +218,47 @@ fu_install_task_check_requirements (FuInstallTask *self,
 		return FALSE;
 	}
 
+	/* check the version formats match if set in the release */
+	tmp = xb_node_query_text (self->component, "custom/value[@key='LVFS::VersionFormat']", NULL);
+	if (tmp != NULL) {
+		FwupdVersionFormat fmt_dev = fu_device_get_version_format (self->device);
+		FwupdVersionFormat fmt_rel = fwupd_version_format_from_string (tmp);
+		if (fmt_rel == FWUPD_VERSION_FORMAT_UNKNOWN &&
+		    (flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+			g_set_error (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOT_SUPPORTED,
+				     "release version format '%s' unsupported",
+				     tmp);
+			return FALSE;
+		}
+		if (fmt_dev == FWUPD_VERSION_FORMAT_UNKNOWN &&
+		    (flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+			g_set_error (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOT_SUPPORTED,
+				     "release version format '%s' but no device version format",
+				     tmp);
+			return FALSE;
+		}
+		if (fmt_dev != fmt_rel) {
+			if ((flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+				g_set_error (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_NOT_SUPPORTED,
+					     "Firmware version formats were different, "
+					     "device was '%s' and release is '%s'",
+					     fwupd_version_format_to_string (fmt_dev),
+					     fwupd_version_format_to_string (fmt_rel));
+				return FALSE;
+			}
+			g_warning ("ignoring version format difference %s:%s",
+				   fwupd_version_format_to_string (fmt_dev),
+				   fwupd_version_format_to_string (fmt_rel));
+		}
+	}
+
+
 	/* compare to the lowest supported version, if it exists */
 	version_lowest = fu_device_get_version_lowest (self->device);
 	if (version_lowest != NULL &&
