@@ -4,15 +4,14 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FU_PLUGIN_LIST_H
-#define __FU_PLUGIN_LIST_H
-
-G_BEGIN_DECLS
+#pragma once
 
 #include <glib-object.h>
 
 #include "fu-plugin.h"
 
+G_BEGIN_DECLS
+
 #define FU_TYPE_PLUGIN_LIST (fu_plugin_list_get_type ())
 G_DECLARE_FINAL_TYPE (FuPluginList, fu_plugin_list, FU, PLUGIN_LIST, GObject)
 
@@ -27,6 +26,3 @@ gboolean	 fu_plugin_list_depsolve		(FuPluginList	*self,
 							 GError		**error);
 
 G_END_DECLS
-
-#endif /* __FU_PLUGIN_LIST_H */
-
