@@ -52,7 +52,7 @@ typedef struct {
 	GPtrArray		*udev_subsystems;
 	FuSmbios		*smbios;
 	GHashTable		*devices;	/* platform_id:GObject */
-	FuMutex			*devices_mutex;
+	GRWLock			 devices_mutex;
 	GHashTable		*report_metadata;	/* key:value */
 	FuPluginData		*data;
 } FuPluginPrivate;
@@ -176,7 +176,7 @@ gpointer
 fu_plugin_cache_lookup (FuPlugin *self, const gchar *id)
 {
 	FuPluginPrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_read_locker_new (priv->devices_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->devices_mutex);
 	g_return_val_if_fail (FU_IS_PLUGIN (self), NULL);
 	g_return_val_if_fail (id != NULL, NULL);
 	g_return_val_if_fail (locker != NULL, NULL);
@@ -197,7 +197,7 @@ void
 fu_plugin_cache_add (FuPlugin *self, const gchar *id, gpointer dev)
 {
 	FuPluginPrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_write_locker_new (priv->devices_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_writer_locker_new (&priv->devices_mutex);
 	g_return_if_fail (FU_IS_PLUGIN (self));
 	g_return_if_fail (id != NULL);
 	g_return_if_fail (locker != NULL);
@@ -217,7 +217,7 @@ void
 fu_plugin_cache_remove (FuPlugin *self, const gchar *id)
 {
 	FuPluginPrivate *priv = GET_PRIVATE (self);
-	g_autoptr(FuMutexLocker) locker = fu_mutex_write_locker_new (priv->devices_mutex);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_writer_locker_new (&priv->devices_mutex);
 	g_return_if_fail (FU_IS_PLUGIN (self));
 	g_return_if_fail (id != NULL);
 	g_return_if_fail (locker != NULL);
@@ -667,7 +667,7 @@ fu_plugin_set_runtime_versions (FuPlugin *self, GHashTable *runtime_versions)
  * @component_id: An AppStream component id, e.g. "org.gnome.Software"
  * @version: A version string, e.g. "1.2.3"
  *
- * Sets a runtime version of a specific dependancy.
+ * Sets a runtime version of a specific dependency.
  *
  * Since: 1.0.7
  **/
@@ -697,7 +697,7 @@ fu_plugin_set_compile_versions (FuPlugin *self, GHashTable *compile_versions)
  * @component_id: An AppStream component id, e.g. "org.gnome.Software"
  * @version: A version string, e.g. "1.2.3"
  *
- * Sets a compile-time version of a specific dependancy.
+ * Sets a compile-time version of a specific dependency.
  *
  * Since: 1.0.7
  **/
@@ -863,9 +863,9 @@ fu_plugin_runner_offline_invalidate (GError **error)
 static gboolean
 fu_plugin_runner_offline_setup (GError **error)
 {
-	const gchar *symlink_target = "/var/lib/fwupd";
 	gint rc;
 	g_autofree gchar *filename = NULL;
+	g_autofree gchar *symlink_target = fu_common_get_path (FU_PATH_KIND_LOCALSTATEDIR_PKG);
 
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
@@ -1345,26 +1345,29 @@ fu_plugin_runner_schedule_update (FuPlugin *self,
 			     FuDevice *device,
 			     FwupdRelease *release,
 			     GBytes *blob_cab,
+			     FwupdInstallFlags flags,
 			     GError **error)
 {
-	gchar tmpname[] = {"XXXXXX.cap"};
+	gchar tmpname[] = {"XXXXXX.cab"};
 	g_autofree gchar *dirname = NULL;
 	g_autofree gchar *filename = NULL;
-	g_autoptr(FuDevice) res_tmp = NULL;
 	g_autoptr(FuHistory) history = NULL;
 	g_autoptr(GFile) file = NULL;
 
 	/* id already exists */
 	history = fu_history_new ();
-	res_tmp = fu_history_get_device_by_id (history, fu_device_get_id (device), NULL);
-	if (res_tmp != NULL &&
-	    fu_device_get_update_state (res_tmp) == FWUPD_UPDATE_STATE_PENDING) {
-		g_set_error (error,
-			     FWUPD_ERROR,
-			     FWUPD_ERROR_ALREADY_PENDING,
-			     "%s is already scheduled to be updated",
-			     fu_device_get_id (device));
-		return FALSE;
+	if ((flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+		g_autoptr(FuDevice) res_tmp = NULL;
+		res_tmp = fu_history_get_device_by_id (history, fu_device_get_id (device), NULL);
+		if (res_tmp != NULL &&
+		    fu_device_get_update_state (res_tmp) == FWUPD_UPDATE_STATE_PENDING) {
+			g_set_error (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_ALREADY_PENDING,
+				     "%s is already scheduled to be updated",
+				     fu_device_get_id (device));
+			return FALSE;
+		}
 	}
 
 	/* create directory */
@@ -1976,7 +1979,7 @@ fu_plugin_init (FuPlugin *self)
 	priv->enabled = TRUE;
 	priv->devices = g_hash_table_new_full (g_str_hash, g_str_equal,
 					       g_free, (GDestroyNotify) g_object_unref);
-	priv->devices_mutex = fu_mutex_new (G_OBJECT_TYPE_NAME(self), "devices");
+	g_rw_lock_init (&priv->devices_mutex);
 	priv->report_metadata = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	for (guint i = 0; i < FU_PLUGIN_RULE_LAST; i++)
 		priv->rules[i] = g_ptr_array_new_with_free_func (g_free);
@@ -2017,7 +2020,8 @@ fu_plugin_finalize (GObject *object)
 		g_hash_table_unref (priv->compile_versions);
 	g_hash_table_unref (priv->devices);
 	g_hash_table_unref (priv->report_metadata);
-	g_object_unref (priv->devices_mutex);
+	g_rw_lock_clear (&priv->devices_mutex);
+	g_free (priv->build_hash);
 	g_free (priv->name);
 	g_free (priv->data);
 	/* Must happen as the last step to avoid prematurely
