@@ -28,10 +28,9 @@
 #include "fwupd-common-private.h"
 #include "fwupd-device-private.h"
 
-#define SYSTEMD_SERVICE			"org.freedesktop.systemd1"
-#define SYSTEMD_OBJECT_PATH		"/org/freedesktop/systemd1"
-#define SYSTEMD_MANAGER_INTERFACE	"org.freedesktop.systemd1.Manager"
-#define SYSTEMD_FWUPD_UNIT		"fwupd.service"
+#ifdef HAVE_SYSTEMD
+#include "fu-systemd.h"
+#endif
 
 /* custom return code */
 #define EXIT_NOTHING_TO_DO		2
@@ -62,56 +61,6 @@ struct FuUtilPrivate {
 	FwupdDeviceFlags	 completion_flags;
 };
 
-static gboolean
-fu_util_stop_daemon (GError **error)
-{
-	g_autoptr(GDBusConnection) connection = NULL;
-	g_autoptr(GDBusProxy) proxy = NULL;
-	g_autoptr(GVariant) val = NULL;
-
-	/* try to stop any already running daemon */
-	connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, error);
-	if (connection == NULL) {
-		g_prefix_error (error, "failed to get bus: ");
-		return FALSE;
-	}
-	proxy = g_dbus_proxy_new_sync (connection,
-					G_DBUS_PROXY_FLAGS_NONE,
-					NULL,
-					SYSTEMD_SERVICE,
-					SYSTEMD_OBJECT_PATH,
-					SYSTEMD_MANAGER_INTERFACE,
-					NULL,
-					error);
-	if (proxy == NULL) {
-		g_prefix_error (error, "failed to find %s: ", SYSTEMD_SERVICE);
-		return FALSE;
-	}
-	val = g_dbus_proxy_call_sync (proxy,
-				      "GetUnit",
-				      g_variant_new ("(s)",
-						     SYSTEMD_FWUPD_UNIT),
-				      G_DBUS_CALL_FLAGS_NONE,
-				      -1,
-				      NULL,
-				      error);
-	if (val == NULL) {
-		g_prefix_error (error, "failed to find %s: ", SYSTEMD_FWUPD_UNIT);
-		return FALSE;
-	}
-	g_variant_unref (val);
-	val = g_dbus_proxy_call_sync (proxy,
-				      "StopUnit",
-				      g_variant_new ("(ss)",
-				     SYSTEMD_FWUPD_UNIT,
-				     "replace"),
-				      G_DBUS_CALL_FLAGS_NONE,
-				      -1,
-				      NULL,
-				      error);
-	return val != NULL;
-}
-
 static gboolean
 fu_util_save_current_state (FuUtilPrivate *priv, GError **error)
 {
@@ -164,8 +113,10 @@ fu_util_start_engine (FuUtilPrivate *priv, FuEngineLoadFlags flags, GError **err
 {
 	g_autoptr(GError) error_local = NULL;
 
-	if (!fu_util_stop_daemon (&error_local))
+#ifdef HAVE_SYSTEMD
+	if (!fu_systemd_unit_stop (fu_util_get_systemd_unit (), &error_local))
 		g_debug ("Failed top stop daemon: %s", error_local->message);
+#endif
 	if (!fu_engine_load (priv->engine, flags, error))
 		return FALSE;
 	if (fu_engine_get_tainted (priv->engine)) {
@@ -637,6 +588,7 @@ fu_util_install_blob (FuUtilPrivate *priv, gchar **values, GError **error)
 			return FALSE;
 		}
 	}
+	priv->flags = FWUPD_INSTALL_FLAG_NO_HISTORY;
 	if (!fu_engine_install_blob (priv->engine, device, blob_fw, priv->flags, error))
 		return FALSE;
 	if (priv->cleanup_blob) {
@@ -1285,6 +1237,30 @@ fu_util_verify_update (FuUtilPrivate *priv, gchar **values, GError **error)
 	return TRUE;
 }
 
+static gboolean
+fu_util_get_history (FuUtilPrivate *priv, gchar **values, GError **error)
+{
+	g_autoptr(GPtrArray) devices = NULL;
+
+	/* load engine */
+	if (!fu_util_start_engine (priv, FU_ENGINE_LOAD_FLAG_NONE, error))
+		return FALSE;
+
+	/* get all devices from the history database */
+	devices = fu_engine_get_history (priv->engine, error);
+	if (devices == NULL)
+		return FALSE;
+
+	/* show each device */
+	for (guint i = 0; i < devices->len; i++) {
+		FwupdDevice *dev = g_ptr_array_index (devices, i);
+		g_autofree gchar *str = fwupd_device_to_string (dev);
+		g_print ("%s\n", str);
+	}
+
+	return TRUE;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -1373,6 +1349,12 @@ main (int argc, char *argv[])
 		     /* TRANSLATORS: command description */
 		     _("Gets details about a firmware file"),
 		     fu_util_get_details);
+	fu_util_cmd_array_add (cmd_array,
+		     "get-history",
+		     NULL,
+		     /* TRANSLATORS: command description */
+		     _("Show history of firmware updates"),
+		     fu_util_get_history);
 	fu_util_cmd_array_add (cmd_array,
 		     "get-updates",
 		     NULL,
@@ -1449,7 +1431,8 @@ main (int argc, char *argv[])
 		     "self-sign",
 		     "TEXT",
 		     /* TRANSLATORS: command description */
-		     _("Sign data using the client certificate"),
+		     C_("command-description",
+			"Sign data using the client certificate"),
 		     fu_util_self_sign);
 	fu_util_cmd_array_add (cmd_array,
 		     "verify-update",
@@ -1496,7 +1479,6 @@ main (int argc, char *argv[])
 	}
 
 	/* set flags */
-	priv->flags |= FWUPD_INSTALL_FLAG_NO_HISTORY;
 	if (allow_reinstall)
 		priv->flags |= FWUPD_INSTALL_FLAG_ALLOW_REINSTALL;
 	if (allow_older)
