@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FU_UDEV_DEVICE_PRIVATE_H
-#define __FU_UDEV_DEVICE_PRIVATE_H
+#pragma once
 
 #include "fu-udev-device.h"
 
@@ -14,5 +13,3 @@ G_BEGIN_DECLS
 void		 fu_udev_device_emit_changed		(FuUdevDevice	*self);
 
 G_END_DECLS
-
-#endif /* __FU_UDEV_DEVICE_PRIVATE_H */
