@@ -1,11 +1,10 @@
 /*
- * Copyright (C) 2017-2018 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2017-2019 Richard Hughes <richard@hughsie.com>
  *
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FU_UDEV_DEVICE_H
-#define __FU_UDEV_DEVICE_H
+#pragma once
 
 #include <glib-object.h>
 #include <gudev/gudev.h>
@@ -32,10 +31,11 @@ const gchar	*fu_udev_device_get_subsystem		(FuUdevDevice	*self);
 guint16		 fu_udev_device_get_vendor		(FuUdevDevice	*self);
 guint16		 fu_udev_device_get_model		(FuUdevDevice	*self);
 guint8		 fu_udev_device_get_revision		(FuUdevDevice	*self);
+guint		 fu_udev_device_get_slot_depth		(FuUdevDevice	*self,
+							 const gchar	*subsystem);
 gboolean	 fu_udev_device_set_physical_id		(FuUdevDevice	*self,
 							 const gchar	*subsystem,
 							 GError		**error);
+void		 fu_udev_device_dump			(FuUdevDevice	*self);
 
 G_END_DECLS
-
-#endif /* __FU_UDEV_DEVICE_H */
