@@ -28,6 +28,10 @@
 #include "fu-util-common.h"
 #include "fwupd-common-private.h"
 
+#ifdef HAVE_SYSTEMD
+#include "fu-systemd.h"
+#endif
+
 /* custom return code */
 #define EXIT_NOTHING_TO_DO		2
 
@@ -351,7 +355,7 @@ fu_util_modify_remote_warning (FuUtilPrivate *priv, FwupdRemote *remote, GError
 		return FALSE;
 
 	/* show and ask user to confirm */
-	g_print ("%s", warning_plain);
+	fu_util_warning_box (warning_plain, 80);
 	if (!priv->assume_yes) {
 		/* ask for permission */
 		g_print ("\n%s [Y|n]: ",
@@ -452,8 +456,7 @@ fu_util_get_devices (FuUtilPrivate *priv, gchar **values, GError **error)
 		g_autofree gchar *tmp = NULL;
 		FwupdDevice *dev = g_ptr_array_index (devs, i);
 		if (!priv->show_all_devices) {
-			if (!fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_UPDATABLE) &&
-			    !fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_SUPPORTED))
+			if (!fu_util_is_interesting_device (dev))
 				continue;
 		}
 		tmp = fwupd_device_to_string (dev);
@@ -982,7 +985,7 @@ fu_util_download_chunk_cb (SoupMessage *msg, SoupBuffer *chunk, gpointer user_da
 	if (header_size < body_length)
 		return;
 
-	/* calulate percentage */
+	/* calculate percentage */
 	percentage = (guint) ((100 * body_length) / header_size);
 	g_debug ("progress: %u%%", percentage);
 	fu_progressbar_update (priv->progressbar, FWUPD_STATUS_DOWNLOADING, percentage);
@@ -1263,7 +1266,7 @@ fu_util_get_releases (FuUtilPrivate *priv, gchar **values, GError **error)
 		fu_util_print_data (_("Version"), fwupd_release_get_version (rel));
 
 		/* TRANSLATORS: section header for the release name */
-		fu_util_print_data (_("Name"), fwupd_release_get_name (rel));
+		fu_util_print_data (_("Name"), fu_util_release_get_name (rel));
 
 		/* TRANSLATORS: section header for the release one line summary */
 		fu_util_print_data (_("Summary"), fwupd_release_get_summary (rel));
@@ -1403,7 +1406,15 @@ fu_util_unlock (FuUtilPrivate *priv, gchar **values, GError **error)
 	if (dev == NULL)
 		return FALSE;
 
-	return fwupd_client_unlock (priv->client, fwupd_device_get_id (dev), NULL, error);
+	if (fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN))
+		priv->completion_flags |= FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN;
+	if (fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_NEEDS_REBOOT))
+		priv->completion_flags |= FWUPD_DEVICE_FLAG_NEEDS_REBOOT;
+
+	if (!fwupd_client_unlock (priv->client, fwupd_device_get_id (dev), NULL, error))
+		return FALSE;
+
+	return fu_util_prompt_complete (priv->completion_flags, TRUE, error);
 }
 
 static gboolean
@@ -1559,7 +1570,7 @@ fu_util_get_updates (FuUtilPrivate *priv, gchar **values, GError **error)
 					    fwupd_release_get_version (rel));
 
 			/* TRANSLATORS: section header for the release name */
-			fu_util_print_data (_("Update Name"), fwupd_release_get_name (rel));
+			fu_util_print_data (_("Update Name"), fu_util_release_get_name (rel));
 
 			/* TRANSLATORS: section header for the release one line summary */
 			fu_util_print_data (_("Update Summary"), fwupd_release_get_summary (rel));
@@ -1887,12 +1898,7 @@ fu_util_update_by_id (FuUtilPrivate *priv, const gchar *device_id, GError **erro
 	}
 
 	/* the update needs the user to restart the computer */
-	if (fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_NEEDS_REBOOT)) {
-		if (!fu_util_prompt_complete (FWUPD_DEVICE_FLAG_NEEDS_REBOOT, TRUE,
-					      error))
-			return FALSE;
-	}
-	return TRUE;
+	return fu_util_prompt_complete (priv->completion_flags, TRUE, error);
 }
 
 static gboolean
@@ -2091,13 +2097,45 @@ fu_util_get_approved_firmware (FuUtilPrivate *priv, gchar **values, GError **err
 	} else {
 		/* TRANSLATORS: approved firmware has been checked by
 		 * the domain administrator */
-		g_print ("%s\n", _("Approved firmware:"));
+		g_print ("%s\n", ngettext ("Approved firmware:",
+					   "Approved firmware:",
+					   g_strv_length (checksums)));
 		for (guint i = 0; checksums[i] != NULL; i++)
 			g_print (" * %s\n", checksums[i]);
 	}
 	return TRUE;
 }
 
+static gboolean
+fu_util_modify_config (FuUtilPrivate *priv, gchar **values, GError **error)
+{
+	/* check args */
+	if (g_strv_length (values) != 2) {
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_INVALID_ARGS,
+				     "Invalid arguments: KEY VALUE expected");
+		return FALSE;
+	}
+	if (!fwupd_client_modify_config (priv->client,
+					 values[0], values[1],
+					 priv->cancellable,
+					 error))
+		return FALSE;
+	if (!priv->assume_yes) {
+		g_print ("%s\n [Y|n]: ",
+			/* TRANSLATORS: configuration changes only take effect on restart */
+			 _("Restart the daemon to make the change effective?"));
+		if (!fu_util_prompt_for_boolean (FALSE))
+			return TRUE;
+	}
+#ifdef HAVE_SYSTEMD
+	if (!fu_systemd_unit_stop (fu_util_get_systemd_unit (), error))
+		return FALSE;
+#endif
+	return TRUE;
+}
+
 static void
 fu_util_ignore_cb (const gchar *log_domain, GLogLevelFlags log_level,
 		   const gchar *message, gpointer user_data)
@@ -2130,6 +2168,46 @@ fu_util_private_free (FuUtilPrivate *priv)
 	g_free (priv);
 }
 
+static gboolean
+fu_util_check_daemon_version (FuUtilPrivate *priv, GError **error)
+{
+	g_autofree gchar *client = g_strdup_printf ("%i.%i.%i",
+						    FWUPD_MAJOR_VERSION,
+						    FWUPD_MINOR_VERSION,
+						    FWUPD_MICRO_VERSION);
+	const gchar *daemon = fwupd_client_get_daemon_version (priv->client);
+
+	if (g_strcmp0 (daemon, client) != 0) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_NOT_SUPPORTED,
+			     /* TRANSLATORS: error message */
+			     _("Unsupported daemon version %s, client version is %s"),
+			     daemon, client);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+static gboolean
+fu_util_check_polkit_actions (GError **error)
+{
+	g_autofree gchar *directory = fu_common_get_path (FU_PATH_KIND_POLKIT_ACTIONS);
+	g_autofree gchar *filename = g_build_filename (directory,
+						       "org.freedesktop.fwupd.policy",
+						       NULL);
+	if (!g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_AUTH_FAILED,
+				     "PolicyKit files are missing, see https://github.com/hughsie/fwupd/wiki/PolicyKit-files-are-missing");
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunused-function"
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(FuUtilPrivate, fu_util_private_free)
@@ -2168,7 +2246,7 @@ main (int argc, char *argv[])
 			_("Allow downgrading firmware versions"), NULL },
 		{ "force", '\0', 0, G_OPTION_ARG_NONE, &force,
 			/* TRANSLATORS: command line option */
-			_("Override plugin warning"), NULL },
+			_("Override warnings and force the action"), NULL },
 		{ "assume-yes", 'y', 0, G_OPTION_ARG_NONE, &priv->assume_yes,
 			/* TRANSLATORS: command line option */
 			_("Answer yes to all questions"), NULL },
@@ -2357,6 +2435,12 @@ main (int argc, char *argv[])
 		     /* TRANSLATORS: firmware approved by the admin */
 		     _("Sets the list of approved firmware."),
 		     fu_util_set_approved_firmware);
+	fu_util_cmd_array_add (cmd_array,
+		     "modify-config",
+		     "KEY,VALUE",
+		     /* TRANSLATORS: sets something in daemon.conf */
+		     _("Modifies a daemon configuration value."),
+		     fu_util_modify_config);
 
 	/* do stuff on ctrl+c */
 	priv->cancellable = g_cancellable_new ();
@@ -2447,6 +2531,27 @@ main (int argc, char *argv[])
 			    "is no longer supported by the upstream developers!\n");
 	}
 
+	/* check that we have at least this version daemon running */
+	if (!fu_util_check_daemon_version (priv, &error)) {
+		g_printerr ("%s\n", error->message);
+		return EXIT_FAILURE;
+	}
+
+#ifdef HAVE_SYSTEMD
+	/* make sure the correct daemon is in use */
+	if ((priv->flags & FWUPD_INSTALL_FLAG_FORCE) == 0 &&
+	    !fu_util_using_correct_daemon (&error)) {
+		g_printerr ("%s\n", error->message);
+		return EXIT_FAILURE;
+	}
+#endif
+
+	/* make sure polkit actions were installed */
+	if (!fu_util_check_polkit_actions (&error)) {
+		g_printerr ("%s\n", error->message);
+		return EXIT_FAILURE;
+	}
+
 	/* run the specified command */
 	ret = fu_util_cmd_array_run (cmd_array, priv, argv[1], (gchar**) &argv[2], &error);
 	if (!ret) {
